<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// A
'activer_plugin' => 'Attiva il plugin',
'affichage' => 'Visualizzazione',
'aide_non_disponible' => 'Questa parte della guida in linea non &egrave; ancora disponibile in italiano.',
'auteur' => 'Autore:',
'avis_acces_interdit' => 'Accesso vietato.',
'avis_article_modifie' => 'Attenzione, @nom_auteur_modif@ ha lavorato su quest\'articolo @date_diff@ minuti fa',
'avis_aucun_resultat' => 'Nessun risultato.',
'avis_chemin_invalide_1' => 'il percorso che hai scelto',
'avis_chemin_invalide_2' => 'non sembra valido. Torna alla pagina precedente e verifica le informazioni fornite.',
'avis_connexion_echec_1' => 'Il collegamento alla base di dati  &egrave; fallito.',
'avis_connexion_echec_2' => 'torna alla pagina precedente e verifica le informazioni fornite.',
'avis_connexion_echec_3' => '<b>N.B.</b> Su molti server si deve <b>chiedere</b> l\'attivazione dell\'accesso alla base di dati prima di poterlo utilizzare. Se &egrave; impossibile collegarsi, verificare che questo passo sia stato fatto.',
'avis_connexion_ldap_echec_1' => 'La connessione al server LDAP &egrave; fallita.',
'avis_connexion_ldap_echec_2' => 'Torna alla pagina precedente e verifica le informazioni fornite. ',
'avis_connexion_ldap_echec_3' => 'In alternativa, non utilizzare il supporto LDAP per importare utenti.',
'avis_conseil_selection_mot_cle' => '<b>Gruppo importante:</b> &egrave; consigliato selezionare una parola chiave in questo gruppo.',
'avis_deplacement_rubrique' => 'Attenzione! Questa rubrica contiene @contient_breves@ breve/i: se vuoi spostarla, spunta questa casella per confermare.',
'avis_destinataire_obligatoire' => 'Devi indicare un destinatario prima di mandare questo messaggio.',
'avis_doublon_mot_cle' => 'Una parola esiste gi&agrave; con questo titolo. Sei sicuro di volerne creare una uguale?',
'avis_erreur_connexion_mysql' => 'Errore di connessione SQL',
'avis_erreur_version_archive' => '<b>Attenzione! Il file @archive@ &egrave; stato creato
    con una versione di SPIP diversa da quella 
    installata.</b> Potranno sorgere notevoli problemi:
    rischio di distruzione del database, vari malfunzionamenti del sito ecc.
    Non confermare questa richiesta d\'importazione.<p>Per ulteriori
    informazioni, vedere <a href="@spipnet@">
    la documentazione di SPIP</a>.</p>',
'avis_espace_interdit' => '<b>Area vietata</b><div>SPIP &egrave; gi&agrave; installato.</div>',
'avis_lecture_noms_bases_1' => 'Il programma di installazione non ha potuto leggere i nomi dei database installati nel server.',
'avis_lecture_noms_bases_2' => 'Nessun database &egrave; disponibile, o la funzione che permette di accedere alla lista database &egrave;
disattivata per motivi sicurezza (verifica con l\'amministratore di sistema).',
'avis_lecture_noms_bases_3' => 'Nel secondo caso, &egrave; probabile che un database con il tuo nome di login sia utilizzabile:',
'avis_non_acces_message' => 'Non hai accesso a questo messaggio.',
'avis_non_acces_page' => 'Non hai accesso a questa pagina.',
'avis_operation_echec' => 'L\'operazione &egrave; fallita.',
'avis_operation_impossible' => 'Operazione impossibile',
'avis_probleme_archive' => 'Problema di lettura del file @archive@',
'avis_site_introuvable' => 'Sito introvabile',
'avis_site_syndique_probleme' => 'Attenzione: si &egrave; verificato un errore nella syndication del sito; il sistema &egrave; temporaneamente fuori uso. Verifica l\'indirizzo del file per la syndication di questo sito (<b>@url_syndic@</b>) e prova nuovamente a recuperare le informazioni remote.',
'avis_sites_probleme_syndication' => 'Si sono verificati alcuni problemi nella syndication di questi siti',
'avis_sites_syndiques_probleme' => 'Si sono verificati alcuni problemi nella syndication di questi siti',
'avis_suppression_base' => 'ATTENZIONE, la cancellazione dei dati &egrave; irreversibile',
'avis_version_mysql' => 'Il vostro server SQL (@version_mysql@)non permette la correzione automatica delle tabelle del database.',

// B
'bouton_acces_ldap' => 'Aggiungi l\'accesso a LDAP ',
'bouton_ajouter' => 'Aggiungi',
'bouton_ajouter_participant' => 'AGGIUNGI UN UTENTE:',
'bouton_annonce' => 'ANNUNCIO',
'bouton_annuler' => 'Annulla',
'bouton_checkbox_envoi_message' => 'possibilit&agrave; di inviare un messaggio',
'bouton_checkbox_indiquer_site' => 'indicare obbligatoriamente un sito Web',
'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'gli amministratori del sito',
'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => 'i redattori',
'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => 'i visitatori del sito pubblico quando scrivono un messaggio in un forum.',
'bouton_checkbox_signature_unique_email' => 'una sola adesione per indirizzo email',
'bouton_checkbox_signature_unique_site' => 'una sola adesione per sito Web',
'bouton_demande_publication' => 'Chiedi la pubblicazione di questo articolo',
'bouton_desactive_tout' => 'Disattiva tutto',
'bouton_desinstaller' => 'Disinstalla',
'bouton_effacer_index' => 'Cancella gli indici',
'bouton_effacer_statistiques' => 'Cancellare le statistiche',
'bouton_effacer_tout' => 'Cancella TUTTO',
'bouton_envoi_message_02' => 'INVIA UN MESSAGGIO',
'bouton_envoyer_message' => 'Messaggio definitivo: Invia',
'bouton_forum_petition' => 'FORUM E PETIZIONE',
'bouton_modifier' => 'Modifica',
'bouton_pense_bete' => 'PROMEMORIA AD USO PERSONALE',
'bouton_radio_activer_messagerie' => 'Attiva la messaggistica interna',
'bouton_radio_activer_messagerie_interne' => 'Attiva la messaggistica interna',
'bouton_radio_activer_petition' => 'Attiva la petizione',
'bouton_radio_afficher' => 'Visualizza',
'bouton_radio_apparaitre_liste_redacteurs_connectes' => 'Comparire nell\'elenco dei redattori collegati',
'bouton_radio_articles_futurs' => 'solo agli articoli inseriti dopo questa modifica (nessuna modifica al database attuale).',
'bouton_radio_articles_tous' => 'a tutti gli articoli senza eccezioni.',
'bouton_radio_articles_tous_sauf_forum_desactive' => 'a tutti gli articoli salvo quelli per cui il forum &egrave; disattivato.',
'bouton_radio_desactiver_messagerie' => 'Disattiva la messaggistica',
'bouton_radio_enregistrement_obligatoire' => 'Registrazione obbligatoria (gli
utenti devono abbonarsi fornendo il loro indirizzo email prima di
poter inviare contributi).',
'bouton_radio_envoi_annonces_adresse' => 'Invia gli annunci all\'indirizzo:',
'bouton_radio_envoi_liste_nouveautes' => 'Invia l\'elenco delle novit&agrave;',
'bouton_radio_moderation_priori' => 'Moderazione a priori (i
contributi saranno pubblicati previa autorizzazione degli
amministratori).',
'bouton_radio_modere_abonnement' => 'solo su abbonamento',
'bouton_radio_modere_posteriori' => 'moderato a posteriori',
'bouton_radio_modere_priori' => 'moderato a priori',
'bouton_radio_non_apparaitre_liste_redacteurs_connectes' => 'Non comparire nell\'elenco dei redattori collegati ',
'bouton_radio_non_envoi_annonces_editoriales' => 'Non inviare annunci editoriali ',
'bouton_radio_non_syndication' => 'Nessuna syndication',
'bouton_radio_pas_petition' => 'Nessuna petizione',
'bouton_radio_petition_activee' => 'Petizione attivata',
'bouton_radio_publication_immediate' => 'Pubblicazione immediata dei messaggi
(i contributi sono pubblicati subito dopo il loro invio, gli amministratori possono
cancellarli successivamente).',
'bouton_radio_sauvegarde_compressee' => 'backup compresso in @fichier@',
'bouton_radio_sauvegarde_non_compressee' => 'backup non compresso in @fichier@',
'bouton_radio_supprimer_petition' => 'Elimina la petizione',
'bouton_radio_syndication' => 'Syndication:',
'bouton_redirection' => 'REINDIRIZZAMENTO',
'bouton_relancer_installation' => 'Rilanciare l\'installazione',
'bouton_restaurer_base' => 'Ripristina il database',
'bouton_suivant' => 'Avanti',
'bouton_tenter_recuperation' => 'Tentare un ripristino',
'bouton_test_proxy' => 'Testare il proxy',
'bouton_vider_cache' => 'Svuota la cache',
'bouton_voir_message' => 'Anteprima messaggio',

// C
'cache_mode_compresse' => 'I file di cache sono salvati in modalit&agrave; compressa.',
'cache_mode_non_compresse' => 'I file di cache sono salvati in modalit&agrave; non compressa.',
'cache_modifiable_webmestre' => 'Questo parametro pu&ograve; essere modificato dal webmaster del sito.',
'calendrier_synchro' => 'Se si utilizza un programma di agenda compatibile con <b>iCal</b>, &egrave; possibile sincronizzare i dati con le informazioni di questo sito',
'config_activer_champs' => 'Attiva i campi seguenti',
'config_choix_base_sup' => 'indicare un database su questo server',
'config_erreur_base_sup' => 'SPIP non ha accesso all\'elenco dei database accessibili ',
'config_info_base_sup' => 'Se si hanno altri database da interrogare attraverso SPIP, con il proprio server SQL o altro, il form sottostante permette di dichiararli. Se si lasciano alcuni campi vuoti verranno utilizzati i dati della connessione al database principale.',
'config_info_base_sup_disponibles' => 'Database supplementari gi&agrave; dichiarati:',
'config_info_enregistree' => 'La nuova configurazione &egrave; stata registrata',
'config_info_logos' => 'Ogni elemento del sito pu&ograve; avere un logo, come pure un &laquo;&nbsp;logo per il roll-over&nbsp;&raquo;',
'config_info_logos_utiliser' => 'Utilizza i logo',
'config_info_logos_utiliser_non' => 'Non utilizzare i logo',
'config_info_logos_utiliser_survol' => 'Utilizzare i logo di roll-over',
'config_info_logos_utiliser_survol_non' => 'Non utilizzare i logo di roll-over',
'config_info_redirection' => 'Attivando questa opzione &egrave; possibile creare degli articoli virtuali, semplici riferimenti di articoli pubblicati su altri siti o al di fuori di SPIP.',
'config_redirection' => 'Articoli virtuali',
'config_titre_base_sup' => 'Dichiarazione di un database supplementare',
'config_titre_base_sup_choix' => 'Scegliere un database supplementare',
'connexion_ldap' => 'Connessione:',
'copier_en_local' => 'Copia in locale',

// D
'date_mot_heures' => 'ore',
'diff_para_ajoute' => 'paragrafo aggiunto',
'diff_para_deplace' => 'Paragrafo spostato',
'diff_para_supprime' => 'Paragrafo cancellato',
'diff_texte_ajoute' => 'Testo aggiunto',
'diff_texte_deplace' => 'Testo spostato',
'diff_texte_supprime' => 'Testo cancellato',
'double_clic_inserer_doc' => 'Doppio clic qui per inserire la scorciatoia nel testo',

// E
'email' => 'email',
'email_2' => 'email:',
'en_savoir_plus' => 'Per saperne di pi&ugrave;',
'entree_adresse_annuaire' => 'Indirizzo della rubrica',
'entree_adresse_email' => 'Il tuo indirizzo email',
'entree_adresse_fichier_syndication' => 'Indirizzo del file di syndication:',
'entree_adresse_site' => '<b>Indirizzo del sito</b> [Obbligatorio]',
'entree_base_donnee_1' => 'Indirizzo del database',
'entree_base_donnee_2' => '(Spesso questo indirizzo coincide con quello dell\'intero sito, qualche volta corrisponde a "localhost", altre volte invece non &egrave; necessario specificarlo.)',
'entree_biographie' => 'La tua biografia in breve.',
'entree_breve_publiee' => 'Questa breve deve essere pubblicata?',
'entree_chemin_acces' => '<b>Inserire</b> il percorso d\'accesso:',
'entree_cle_pgp' => 'Chiave PGP',
'entree_contenu_rubrique' => '(Contenuto della rubrica in qualche parola)',
'entree_description_site' => 'Descrizione del sito',
'entree_identifiants_connexion' => 'Identificativo di connessione...',
'entree_informations_connexion_ldap' => 'Inserisci in questo form gli estremi per la connessione alla tua rubrica LDAP.
Se non conosci queste informazioni, richiedile all\'amministratore del sistema o della rete.',
'entree_infos_perso' => 'Chi sei?',
'entree_interieur_rubrique' => 'All\'interno della rubrica:',
'entree_liens_sites' => '<b>Link ipertestuale</b> (riferimento, sito da visitare...)',
'entree_login' => 'Login',
'entree_login_connexion_1' => 'Il login di connessione',
'entree_login_connexion_2' => '(Corrisponde a volte al login d\'accesso via FTP; in alcuni casi non occorre specificare nulla)',
'entree_login_ldap' => 'Login LDAP iniziale',
'entree_mot_passe' => 'Password',
'entree_mot_passe_1' => 'La password di connessione',
'entree_mot_passe_2' => '(Corrisponde a volte alla password d\'accesso via FTP; in alcuni casi non occorre specificare nulla)',
'entree_nom_fichier' => 'Inserire il nome del file @texte_compresse@:',
'entree_nom_pseudo' => 'Nome o pseudonimo',
'entree_nom_pseudo_1' => '(Nome o pseudonimo)',
'entree_nom_site' => 'Nome del tuo sito',
'entree_nouveau_passe' => 'Nuova password',
'entree_passe_ldap' => 'Password',
'entree_port_annuaire' => 'Il numero di porta della rubrica',
'entree_signature' => 'Firma',
'entree_texte_breve' => 'Testo della breve',
'entree_titre_obligatoire' => '<b>Titolo</b> [Obbligatorio]<br />',
'entree_url' => 'Indirizzo (URL) del sito',
'erreur_plugin_desinstalation_echouee' => 'La disinstallazione del plugin &egrave; fallita. In ogni caso potete disattivarlo.',
'erreur_plugin_fichier_absent' => 'File non presente',
'erreur_plugin_fichier_def_absent' => 'File di definizioni non presente',
'erreur_plugin_nom_fonction_interdit' => 'Nome di funzione non possibile',
'erreur_plugin_nom_manquant' => 'Nome del plugin mancante',
'erreur_plugin_prefix_manquant' => 'Spazio per il nome del plugin non definito',
'erreur_plugin_tag_plugin_absent' => '&lt;plugin&gt; mancante nel file di definizione',
'erreur_plugin_version_manquant' => 'Versione del plugin mancante',

// F
'forum_info_original' => 'originale',

// H
'htaccess_a_simuler' => 'Attenzione: la configurazione del tuo HTTP server ignora il file @htaccess@. Per garantire un buon livello di sicurezza devi modificare la configurazione del server per questa impostazione, oppure devi assicurarti che la costante @constantes@ (che potrebbe essere definita nel file mes_options.php) sia valorizzata con una valore di directory al di fuori di @document_root@.',
'htaccess_inoperant' => 'htaccess non attivo',

// I
'ical_info1' => 'Questa pagina elenca diversi metodi per rimanere in contatto con le varie attivit&agrave; del sito.',
'ical_info2' => 'Per ulteriori informazioni su tutte queste tecniche, non esitate a consultare <a href="@spipnet@">la documentazione di SPIP</a>.',
'ical_info_calendrier' => 'Sono disponibili due calendari. Il primo &egrave; una mappa del sito che annuncia tutti gli articoli pubblicati. Il secondo contiene gli annunci editoriali e gli ultimi messaggi privati: &egrave; un\'area riservata, mediante identificativo personale, che &egrave; possibile modificare in qualsiasi momento rinnovando la password personale.',
'ical_lien_rss_breves' => 'Syndication delle brevi del sito',
'ical_methode_http' => 'Download',
'ical_methode_webcal' => 'Sincronizzazione (webcal://)',
'ical_texte_js' => 'Una linea in javascript permette di visualizzare, con molta semplicit&agrave; e su qualsiasi tipo di sito, gli articoli recenti pubblicati su questo sito.',
'ical_texte_prive' => 'Questo calendario, ad uso strettamente privato, d&agrave; informazioni sull\'attivit&agrave; redazionale privata di questo sito (impegni e appuntamenti personali, articoli e brevi proposti...).',
'ical_texte_public' => 'Questo calendario permette di monitorare l\'attivit&agrave; pubblica del sito (articoli e brevi pubblicati).',
'ical_texte_rss' => '&Egrave; possibile mettere in syndication le novit&agrave; di questo sito con qualsiasi lettore di file in formato XML/RSS (Rich Site Summary). Questo &egrave; il medesimo formato che permette a SPIP di leggere le novit&agrave; pubblicate su altri siti che utilizzano un formato di scambio compatibile.',
'ical_titre_js' => 'Javascript',
'ical_titre_mailing' => 'Mailing-list',
'ical_titre_rss' => 'File di syndication',
'icone_activer_cookie' => 'Attiva il cookie di corrispondenza',
'icone_admin_plugin' => 'Gestione dei plugin',
'icone_afficher_auteurs' => 'Pubblica gli autori',
'icone_afficher_visiteurs' => 'Pubblica i visitatori',
'icone_arret_discussion' => 'Non partecipare pi&ugrave; a questa discussione',
'icone_calendrier' => 'Calendario',
'icone_creation_groupe_mots' => 'Crea un nuovo gruppo',
'icone_creation_mots_cles' => 'Crea una nuova parola chiave',
'icone_creer_auteur' => 'Crea un nuovo autore ed associalo a questo articolo',
'icone_creer_mot_cle' => 'Crea una nuova parola chiave e collegala a questo articolo',
'icone_creer_mot_cle_breve' => 'Creare una nuova parola chiave e collegarla a questa breve',
'icone_creer_mot_cle_rubrique' => 'Creare una nuova parola chiave e collegarla a questa rubrica',
'icone_creer_mot_cle_site' => 'Creare una nuova parola chiave e collegarla a questo sito',
'icone_creer_rubrique_2' => 'Crea una nuova rubrica',
'icone_ecrire_nouvel_article' => 'Le brevi contenute nella rubrica',
'icone_envoyer_message' => 'Invia questo messaggio',
'icone_evolution_visites' => 'Evoluzione delle visite<br />@visites@ visite',
'icone_modif_groupe_mots' => 'Modifica questo gruppo',
'icone_modifier_article' => 'Modifica l\'articolo',
'icone_modifier_breve' => 'Modifica la breve',
'icone_modifier_message' => 'Modifica il messaggio',
'icone_modifier_mot' => 'Modifica questa parola chiave',
'icone_modifier_rubrique' => 'Modifica la rubrica',
'icone_modifier_site' => 'Modifica il sito',
'icone_poster_message' => 'Invia un messaggio',
'icone_publier_breve' => 'Pubblica questa breve',
'icone_referencer_nouveau_site' => 'Inserisci un nuovo sito in repertorio',
'icone_refuser_breve' => 'Rifiuta questa breve',
'icone_relancer_signataire' => 'Rilanciare il firmatario',
'icone_retour' => 'Indietro',
'icone_retour_article' => 'Torna all\'articolo',
'icone_suivi_forum' => 'Andamento del forum pubblico: @nb_forums@&nbsp;contributi',
'icone_supprimer_cookie' => 'Elimina il cookie di corrispondenza',
'icone_supprimer_groupe_mots' => 'Elimina il gruppo',
'icone_supprimer_rubrique' => 'Elimina la rubrica',
'icone_supprimer_signature' => 'Cancella l\'adesione',
'icone_valider_signature' => 'Conferma l\'adesione',
'icone_voir_sites_references' => 'Vedi i siti in repertorio',
'icone_voir_tous_mots_cles' => 'Vedi tutte le parole chiave',
'image_administrer_rubrique' => 'Puoi amministrare questa rubrica',
'info_1_article' => '1 articolo',
'info_1_breve' => '1 breve',
'info_1_site' => '1 sito',
'info_activer_cookie' => 'Se vuoi puoi attivare un <b>cookie di corrispondenza</b>, che ti permetter&agrave;
di passare facilmente dal sito pubblico all\'interfaccia privata.',
'info_activer_forum_public' => '<i>Per attivare i forum pubblici, scegli il tipo
di moderazione predefinito:</i>',
'info_admin_gere_rubriques' => 'Questo amministratore gestisce le seguenti rubriche:',
'info_admin_gere_toutes_rubriques' => 'Questo amministratore gestisce <b>tutte le rubriche</b>.',
'info_admin_statuer_webmestre' => 'Dai a questo amministratore i privilegi di webmaster',
'info_admin_webmestre' => 'Questo amministratore &egrave; un <b>webmaster</b>',
'info_administrateur' => 'Amministratore',
'info_administrateur_1' => 'Amministratore',
'info_administrateur_2' => 'del sito (<i>da utilizzare con prudenza</i>)',
'info_administrateur_site_01' => 'Se sei amministratore del sito,',
'info_administrateur_site_02' => 'clicca qui',
'info_administrateurs' => 'Amministratori',
'info_administrer_rubrique' => 'Puoi amministrare questa rubrica',
'info_adresse' => 'all\'indirizzo:',
'info_adresse_email' => 'INDIRIZZO EMAIL:',
'info_adresse_url' => 'Indirizzo (URL) del sito pubblico',
'info_afficher_visites' => 'Visualizzare le visite per:',
'info_affichier_visites_articles_plus_visites' => 'Mostra le visite per <b>gli articoli pi&ugrave; letti dall\'inaugurazione del sito:</b>',
'info_aide_en_ligne' => 'Guida in linea SPIP',
'info_ajout_image' => 'Quando aggiungi delle immagini come documenti allegati ad un articolo,
SPIP pu&ograve; creare delle thumbnail (miniature) delle
immagini inserite. Ci&ograve; permette ad esempio di creare in automatico una galleria di immagini o un portfolio.',
'info_ajout_participant' => 'Si &egrave; aggiunto il seguente partecipante:',
'info_ajouter_rubrique' => 'Aggiungi un\'altra rubrica da amministrare:',
'info_annonce_nouveautes' => 'Annuncio delle novit&agrave;',
'info_anterieur' => 'anteriore',
'info_appliquer_choix_moderation' => 'Questa scelta di moderazione verr&agrave; applicata:',
'info_article' => 'articolo',
'info_article_2' => 'articoli',
'info_article_a_paraitre' => 'Gli articoli postdatati da pubblicare',
'info_articles_02' => 'articoli',
'info_articles_2' => 'Articoli',
'info_articles_auteur' => 'Articoli di questo autore',
'info_articles_lies_mot' => 'Gli articoli collegati a questa parola chiave',
'info_articles_trouves' => 'Articoli trovati',
'info_articles_trouves_dans_texte' => 'Articoli trovati (ricerca nel testo)',
'info_attente_validation' => 'I tuoi articoli in attesa di convalida',
'info_aujourdhui' => 'oggi: ',
'info_auteur_message' => 'AUTORE DEL MESSAGGIO:',
'info_auteurs' => 'Gli autori',
'info_auteurs_par_tri' => 'Autori@partri@',
'info_auteurs_trouves' => 'Autori trovati',
'info_authentification_externe' => 'Autenticazione esterna',
'info_avertissement' => 'Avvertimento',
'info_barre_outils' => 'con la barra degli strumenti?',
'info_base_installee' => 'La struttura del vostro database &egrave; installata.',
'info_base_restauration' => 'Il database &egrave; in fase di ripristino.',
'info_bloquer' => 'bloccare',
'info_breves' => 'Il tuo sito dovr&agrave; utilizzare il sistema di brevi?',
'info_breves_03' => 'brevi',
'info_breves_liees_mot' => 'Le brevi collegate a questa parola chiave',
'info_breves_touvees' => 'Brevi trovate',
'info_breves_touvees_dans_texte' => 'Brevi trovate (nel testo)',
'info_changer_nom_groupe' => 'Cambiare il nome di questo gruppo:',
'info_chapeau' => 'Introduzione',
'info_chapeau_2' => 'Introduzione:',
'info_chemin_acces_1' => 'Opzioni: <b>Percorso d\'accesso ai dati nell\'elenco</b>',
'info_chemin_acces_2' => '&Egrave; necessario specificare il  percorso per accedere ai dati nell\'elenco. Questa informazione &egrave; indispensabile al fine di leggere i profili utente in esso contenuti.',
'info_chemin_acces_annuaire' => 'Opzioni: <b>Percorso d\'accesso ai dati nell\'elenco</b>',
'info_choix_base' => 'Terza fase: ',
'info_classement_1' => '<sup>o</sup> su @liste@',
'info_classement_2' => '<sup>o</sup> su @liste@',
'info_code_acces' => 'Non dimenticare i tuoi codici d\'accesso!',
'info_comment_lire_tableau' => 'Come leggere questa tabella',
'info_compresseur_gzip' => '<b>N.&nbsp;B.&nbsp;:</b> Si raccomanda di verificare preventivamente se il provider comprime gi&agrave; in maniera sistematica gli script php; a tal fine &egrave; possibile utilizzare, per esempio,  il seguente servizio: @testgzip@',
'info_compresseur_texte' => 'Se il proprio server non comprime automaticamente le pagine HTML per inviarle ai visitatori, &egrave; possibile tentare di forzare la compressione per diminuire il peso delle pagine da scaricare. <b>Attenzione</b>: ci&ograve; pu&ograve; rallentare notevolmente alcuni server.',
'info_compresseur_titre' => 'Ottimizzazione e compressione',
'info_config_forums_prive' => 'Nell\'area riservata del sito &egrave; possibile attivare diversi tipi di forum:',
'info_config_forums_prive_admin' => 'Un forum riservato agli amministratori del sito:',
'info_config_forums_prive_global' => 'Un forum globale, aperto a tutti i redattori:',
'info_config_forums_prive_objets' => 'Un forum per ogni articolo, breve, sito repertoriato, ecc.:',
'info_config_suivi' => 'Se questo indirizzo corrisponde a una mailing-list, &egrave; possibile indicare qui sotto l\'indirizzo al quale i partecipanti del sito possono iscriversi. Questo indirizzo pu&ograve; essere una URL (per esempio la pagina di iscrizione via Web alla lista), oppure un indirizzo email che contiene un Oggetto specifico (per esempio: <tt>@adresse_suivi@?subject=subscribe</tt>):',
'info_config_suivi_explication' => '&Egrave; possibile abbonarsi alla mailing-list di questo sito. Verranno spedite per email le notifiche degli articoli e delle brevi proposte per la pubblicazione.',
'info_confirmer_passe' => 'Conferma la nuova password:',
'info_conflit_edition_avis_non_sauvegarde' => 'Attenzione, i campi seguenti sono gi&agrave; stati modificati. Quindi le vostre modifiche su questi campi non sono state registrate.',
'info_conflit_edition_differences' => 'Differenze:',
'info_conflit_edition_version_enregistree' => 'La versione registrata:',
'info_conflit_edition_votre_version' => 'La tua versione:',
'info_connexion_base' => 'Prova di connessione al database',
'info_connexion_base_donnee' => 'Connessione al proprio database',
'info_connexion_ldap_ok' => 'La connessione LDAP &egrave; riuscita.</b><p> &Egrave; possibile passare alla fase successiva.</p>',
'info_connexion_mysql' => 'La connessione a SQL',
'info_connexion_ok' => 'La connessione &egrave; riuscita.',
'info_contact' => 'Contatti',
'info_contenu_articles' => 'Contentuto degli articoli',
'info_creation_mots_cles' => 'In questa pagina &egrave; possibile creare e configurare le parole chiave del sito',
'info_creation_paragraphe' => '(Per creare dei paragrafi indipendenti, lasciare fra loro delle righe vuote.)',
'info_creation_rubrique' => 'Prima di poter scrivere degli articoli, <br />devi creare almeno una rubrica.<br />',
'info_creation_tables' => 'Creazione delle tabelle nel database',
'info_creer_base' => '<b>Creare</b> un nuovo database:',
'info_dans_groupe' => 'Nel gruppo:',
'info_dans_rubrique' => 'Nella rubrica:',
'info_date_publication_anterieure' => 'Data di redazione anteriore:',
'info_date_referencement' => 'DATA DI INSERIMENTO IN REPERTORIO DI QUESTO SITO:',
'info_delet_mots_cles' => 'Hai chiesto
di eliminare la parola chiave
<b>@titre_mot@</b> (@type_mot@). Essendo quest\'ultima collegata a
<b>@texte_lie@</b>, &egrave; necessario confermare la decisione:',
'info_derniere_etape' => 'Finito!',
'info_derniere_syndication' => 'L\'ultima <em>syndication</em> di questo sito &egrave; stata effettuata il',
'info_derniers_articles_publies' => 'I tuoi ultimi articoli pubblicati',
'info_desactiver_forum_public' => 'Disattiva l\'uso dei forum pubblici.
I forum pubblici potranno essere autorizzati di volta in volta
sui singoli articoli; saranno invece proibiti nelle rubriche, nelle brevi, ecc',
'info_desactiver_messagerie_personnelle' => 'Puoi attivare o disattivare il sistema di messaggistica personale su questo sito.',
'info_descriptif' => 'Descrizione:',
'info_desinstaller_plugin' => 'elimina i dati e disattiva il plug-in',
'info_discussion_cours' => 'Discussioni in corso',
'info_ecrire_article' => 'Prima di poter scrivere degli articoli, devi creare almeno una rubrica.',
'info_email_envoi' => 'Indirizzo email del mittente (opzionale)',
'info_email_envoi_txt' => 'Indicare qui l\'indirizzo da utilizzare per l\'invio degli email (come impostazione predefinita l\'indirizzo del destinatario sar&agrave; utilizzato come indirizzo del mittente):',
'info_email_webmestre' => 'Indirizzo email del webmaster (opzionale)',
'info_entrer_code_alphabet' => 'Inserisci il codice dell\'alfabeto da utilizzare:',
'info_envoi_email_automatique' => 'Invio di email automatico',
'info_envoi_forum' => 'Notifica dei forum agli autori degli articoli',
'info_envoyer_maintenant' => 'Invia adesso',
'info_erreur_restauration' => 'Errore di ripristino: file inesistente.',
'info_etape_suivante' => 'Passare alla fase successiva',
'info_etape_suivante_1' => 'Puoi passare alla fase successiva.',
'info_etape_suivante_2' => 'Puoi passare alla fase successiva.',
'info_exportation_base' => 'esportazione del database verso @archive@',
'info_facilite_suivi_activite' => 'Al fine di facilitare il monitoraggio
dell\'attivit&agrave; editoriale del sito, SPIP pu&ograve; far pervenire via email,
per esempio ad una mailing-list dei redattori, l\'annuncio delle domande di
pubblicazione e di convalida degli articoli.',
'info_fichiers_authent' => 'File d\'autenticazione ".htpasswd"',
'info_fonctionnement_forum' => 'Funzionamento del forum:',
'info_forum_administrateur' => 'forum degli amministratori',
'info_forum_interne' => 'forum interno',
'info_forum_ouvert' => 'Nell\'area riservata del sito, &egrave; disponibile un forum per
tutti i redattori registrati. &Egrave; anche possibile attivare un
secondo forum riservato ai soli amministratori.',
'info_forum_statistiques' => 'Statistiche delle visite',
'info_forums_abo_invites' => 'Il sito comprende dei forum accessibili solo a utenti registrati. Nel sito pubblico &egrave; quindi presente una pagina d\'iscrizione.',
'info_gauche_admin_effacer' => '<b>Questa pagina &egrave; accessibile solo ai responsabili del sito.</b><p> Permette l\'accesso alle diverse funzioni di manutenzione tecnica. Alcune di esse richiedono una specifica procedura di identificazione, eseguibile grazie a un accesso FTP.</p>',
'info_gauche_admin_tech' => '<b>Questa pagina &egrave; accessibile solo ai responsabili del sito.</b><p> Permette l\'accesso alle diverse funzioni di manutenzione tecnica. Alcune di esse richiedono una specifica procedura di identificazione, eseguibile grazie a un accesso FTP.</p>', # MODIF
'info_gauche_admin_vider' => '<b>Questa pagina &egrave; accessibile solo ai responsabili del sito.</b><p> Permette l\'accesso alle diverse funzioni di manutenzione tecnica. Alcune di esse richiedono una specifica procedura di identificazione, eseguibile grazie ad un accesso FTP.</p>', # MODIF
'info_gauche_auteurs' => 'Elenco di tutti gli autori del sito.
Il loro status &egrave; indicato dal colore dell\'icona (redattore = giallo; amministratore = verde).',
'info_gauche_auteurs_exterieurs' => 'Gli autori esterni, senza accesso al sito, sono indicati da un\'icona blu;
gli autori eliminati, invece, da un cestino.',
'info_gauche_messagerie' => 'Il sistema di messaggistica permette di scambiare dei messaggi tra redattori, di conservare dei memo (promemoria ad uso personale) o di pubblicare degli annunci nel pannello di controllo dell\'area riservata (se sei amministratore).',
'info_gauche_numero_auteur' => 'AUTORE NUMERO',
'info_gauche_numero_breve' => 'BREVE NUMERO',
'info_gauche_statistiques_referers' => 'Questa pagina presenta un elenco dei siti che contengono link verso il tuo (<i>referrer</i>). Questo elenco &egrave; valido per&ograve; solo per oggi essendo azzerato ogni 24 ore.',
'info_gauche_suivi_forum' => 'La pagina di <i>monitoraggio dei forum</i> &egrave; uno strumento di gestione del sito (e non uno spazio di discussione o di redazione). In essa sono pubblicati tutti i contributi del forum pubblico di quest\'articolo, permettendone la gestione.',
'info_gauche_suivi_forum_2' => 'La pagina di <i>monitoraggio dei forum</i> &egrave; uno strumento di gestione del sito (e non uno spazio di discussione o di redazione). In essa sono pubblicati tutti i contributi dei forum del sito, sia quelli del sito pubblico che quelli dell\'area riservata, permettendone la gestione.',
'info_gauche_visiteurs_enregistres' => 'Trovi qui i visitatori registrati allo spazio
pubblico del sito (forum su abbonamento).',
'info_generation_miniatures_images' => 'Generazione di thumbnail di immagini',
'info_gerer_trad' => 'Gestire i link di traduzione?',
'info_groupe_important' => 'Gruppo importante',
'info_hebergeur_desactiver_envoi_email' => 'Alcuni hoster disattivano  l\'invio automatico di email
dai loro server. In questo caso, le funzionalit&agrave; di SPIP di seguito riportate non funzioneranno.',
'info_hier' => 'ieri:',
'info_historique' => 'Revisioni:',
'info_historique_activer' => 'Attivare la gestione delle revisioni',
'info_historique_affiche' => 'Visualizzare questa versione',
'info_historique_comparaison' => 'confronto',
'info_historique_desactiver' => 'Disattivare la gestione delle revisioni',
'info_historique_lien' => 'Mostra la cronologia delle modifiche',
'info_historique_texte' => 'La gestione delle revisioni permette di conservare traccia di tutte le modifiche effettuate su un articolo, mostrando le differenze fra le sue versioni successive.',
'info_historique_titre' => 'Gestione delle revisioni',
'info_identification_publique' => 'La tua identit&agrave; pubblica...',
'info_image_process' => 'Seleziona il metodo migliore per la creazione delle anteprime cliccando sull\'immagine corrispondente.',
'info_image_process2' => '<b>N.B.</b> <i>Se non appare alcuna immagine, ci&ograve; significa che la configurazione del server non permette l\'uso di alcune funzioni grafiche. Se si desidera utilizzarle, rivolgersi al responsabile tecnico chiedendo di installare le estensioni "GD" o "Imagick".</i>',
'info_images_auto' => 'Immagini elaborate automaticamente',
'info_informations_personnelles' => 'Informazioni personali',
'info_inscription_automatique' => 'Iscrizione automatica di nuovi redattori',
'info_jeu_caractere' => 'Set di caratteri del sito',
'info_jours' => 'giorni',
'info_laisser_champs_vides' => 'lasciare questi campi vuoti)',
'info_langues' => 'Lingua del sito',
'info_ldap_ok' => 'L\'autenticazione LDAP &egrave; installata.',
'info_lien_hypertexte' => 'Link ipertestuale:',
'info_liens_syndiques_1' => 'link in syndication',
'info_liens_syndiques_2' => 'sono in attesa di convalida.',
'info_liens_syndiques_3' => 'forum',
'info_liens_syndiques_4' => 'sono',
'info_liens_syndiques_5' => 'forum',
'info_liens_syndiques_6' => '&egrave;',
'info_liens_syndiques_7' => 'in attesa di convalida',
'info_liste_redacteurs_connectes' => 'Elenco dei redattori collegati',
'info_login_existant' => 'Questo login esiste gi&agrave;.',
'info_login_trop_court' => 'Login troppo corto.',
'info_logos' => 'I logo',
'info_maximum' => 'massimo:',
'info_meme_rubrique' => 'Nella stessa rubrica',
'info_message' => 'Messaggio del ',
'info_message_efface' => 'MESSAGGIO CANCELLATO',
'info_message_en_redaction' => 'I tuoi messaggi in corso di redazione',
'info_message_technique' => 'Messaggio tecnico:',
'info_messagerie_interne' => 'Sistema di messaggistica interna',
'info_mise_a_niveau_base' => 'aggiornamento del database SQL',
'info_mise_a_niveau_base_2' => '{{Attenzione!}} &Egrave; stata installata una versione
dei file di SPIP {precedente} rispetto a quella che era in uso per questo sito:
le informazioni contenute nel database sono probabilmente andate perse.<br />{{Reinstallare i file di SPIP.}}',
'info_mode_fonctionnement_defaut_forum_public' => 'Modo di funzionamento predefinito dei forum pubblici',
'info_modifier_auteur' => 'Modifica l\'autore:',
'info_modifier_breve' => 'Modifica la breve:',
'info_modifier_mot' => 'Modifica la parola chiave:',
'info_modifier_rubrique' => 'Modifica la rubrica:',
'info_modifier_titre' => 'Modifica: @titre@',
'info_mon_site_spip' => 'Il mio sito SPIP',
'info_mot_sans_groupe' => '(Parole chiave senza gruppo...)',
'info_moteur_recherche' => 'Motore di ricerca integrato',
'info_mots_cles' => 'Le parole chiave',
'info_mots_cles_association' => 'Le parole chiave di questo gruppo possono essere associate:',
'info_moyenne' => 'media: ',
'info_multi_articles' => 'Attivare il menu della lingua negli articoli?',
'info_multi_cet_article' => 'Lingua di questo articolo:',
'info_multi_langues_choisies' => 'Selezionare di seguito le lingue disponibili per i redattori del sito.
  Le lingue gi&agrave; utilizzate nel sito (visualizzate per prime) non possono essere disattivate.',
'info_multi_rubriques' => 'Attivare il menu della lingua nelle rubriche?',
'info_multi_secteurs' => '... solo per le rubriche collocate nella {root} del sito?',
'info_nom' => 'Nome',
'info_nom_destinataire' => 'Nome del destinatario',
'info_nom_site' => 'Nome del tuo sito',
'info_nom_site_2' => '<b>Nome del sito</b> [Obbligatorio]',
'info_nombre_articles' => '@nb_articles@ articoli,',
'info_nombre_breves' => '@nb_breves@ brevi, ',
'info_nombre_partcipants' => 'PARTECIPANTI ALLA DISCUSSIONE:',
'info_nombre_rubriques' => '@nb_rubriques@ rubriche,',
'info_nombre_sites' => '@nb_sites@ siti, ',
'info_non_deplacer' => 'Non spostare...',
'info_non_envoi_annonce_dernieres_nouveautes' => 'SPIP pu&ograve; inviare regolarmente annunci sulle ultime novit&agrave; del sito
(articoli e brevi recentemente pubblicati).',
'info_non_envoi_liste_nouveautes' => 'Non inviare l\'elenco delle novit&agrave;',
'info_non_modifiable' => 'non pu&ograve; essere modificato',
'info_non_suppression_mot_cle' => 'non voglio cancellare questa parola chiave.',
'info_notes' => 'Note',
'info_nouveaux_message' => 'Nuovi messaggi',
'info_nouvel_article' => 'Nuovo articolo',
'info_nouvelle_traduction' => 'Nuova traduzione:',
'info_numero_article' => 'ARTICOLO NUMERO:',
'info_obligatoire_02' => '[Obbligatorio]',
'info_option_accepter_visiteurs' => 'Accetta l\'iscrizione di utenti del sito pubblico',
'info_option_email' => 'Quando un visitatore del sito inserisce un nuovo messaggio nel forumassociato a un articolo, gli autori di quest\'ultimo possono essereavvertiti via email. Per ogni tipo di forum, indica se desideri utilizzare quest\'opzione.',
'info_option_faire_suivre' => 'Segnala i nuovi messaggi',
'info_option_ne_pas_accepter_visiteurs' => 'Rifiuta l\'iscrizione di utenti',
'info_option_ne_pas_faire_suivre' => 'Non segnalare i nuovi messaggi',
'info_options_avancees' => 'OPZIONE AVANZATA',
'info_ortho_activer' => 'Attivare il controllo ortografico',
'info_ortho_desactiver' => 'Disattivare il controllo ortografico',
'info_ou' => 'o... ',
'info_oui_suppression_mot_cle' => 'voglio cancellare definitivamente questa parola chiave.',
'info_page_interdite' => 'Pagina riservata',
'info_par_nom' => 'per nome',
'info_par_nombre_article' => 'per numero di articoli',
'info_par_statut' => 'per status',
'info_par_tri' => '\'(per @tri@)\'',
'info_pas_de_forum' => 'nessun forum',
'info_passe_trop_court' => 'Password troppo corta.',
'info_passes_identiques' => 'Le due password non sono uguali.',
'info_pense_bete_ancien' => 'I vecchi memo', # MODIF
'info_plus_cinq_car' => 'pi&ugrave; di 5 caratteri',
'info_plus_cinq_car_2' => '(Pi&ugrave; di 5 caratteri)',
'info_plus_trois_car' => '(Pi&ugrave; di 3 caratteri)',
'info_popularite' => 'popolarit&agrave;:&nbsp;@popularite@; visite:&nbsp;@visites@',
'info_popularite_2' => 'popolarit&agrave; del sito: ',
'info_popularite_3' => 'popolarit&agrave;:&nbsp;@popularite@; visite:&nbsp;@visites@',
'info_popularite_4' => 'popolarit&agrave;:&nbsp;@popularite@; visite:&nbsp;@visites@',
'info_post_scriptum' => 'Post&nbsp;Scriptum',
'info_post_scriptum_2' => 'Post&nbsp;Scriptum:',
'info_pour' => 'per',
'info_preview_admin' => 'Solo gli amministratori possono visualizzare l\'anteprima del sito',
'info_preview_comite' => 'Tutti i redattori possono visualizzare l\'anteprima del sito',
'info_preview_desactive' => 'L\'anteprima del sito &egrave; totalmente disattivata',
'info_preview_texte' => '&Egrave; possibile visualizzare un\'anteprima del sito comprendente anche gli articoli e le brevi "proposti" per la pubblicazione. Questa funzionalit&agrave; pu&ograve; essere disattivata, consentita solo agli amministratori o a tutti i redattori.',
'info_principaux_correspondants' => 'Corrispondenti principali',
'info_procedez_par_etape' => 'procedere passo dopo passo',
'info_procedure_maj_version' => '&egrave; necessario avviare la procedura di aggiornamento per adattare
il database alla nuova versione di SPIP.',
'info_proxy_ok' => 'Test del proxy riuscito.',
'info_ps' => 'P.S.',
'info_publier' => 'pubblicare',
'info_publies' => 'I tuoi articoli pubblicati',
'info_question_accepter_visiteurs' => 'I modelli di pagina del sito prevedono la registrazione di utenti senza accesso all\'area riservata. Attivare la seguente funzionalit&agrave;:',
'info_question_activer_compactage_css' => 'Si desidera attivare la compressione dei fogli di stile (CSS)?',
'info_question_activer_compactage_js' => 'Si desidera attivare la compressione degli script (javascript)?',
'info_question_activer_compresseur' => 'Si desidera attivare la compressione del flusso HTTP?',
'info_question_gerer_statistiques' => 'Il sito deve gestire le statistiche delle visite?',
'info_question_inscription_nouveaux_redacteurs' => 'Accettate le iscrizioni di nuovi redattori
direttamente  dal sito pubblico? In caso affermativo, i visitatori potranno iscriversi
grazie ad un modulo automatizzato e accedere all\'area riservata per proporre
i propri articoli. <blockquote><i>Durante la fase d\'iscrizione,
gli utenti ricevono automaticamente un email
che fornisce loro i codici d\'accesso al sito privato. Alcuni
hoster disattivano l\'invio di email dai propri server: in questo caso, l\'iscrizione automatica &egrave;
impossibile.', # MODIF
'info_question_mots_cles' => 'Vuoi utilizzare le parole chiave nel sito?',
'info_question_proposer_site' => 'Chi pu&ograve; proporre i siti da citare?',
'info_question_utilisation_moteur_recherche' => 'Desideri utilizzare il motore di ricerca integrato di SPIP?
(disattivandolo viene velocizzato il funzionamento del sistema)',
'info_question_vignettes_referer' => 'Quando si consultano le statistiche &egrave; possibile visualizzare delle anteprime dei siti di origine delle visite',
'info_question_vignettes_referer_non' => 'Non visualizzare la cattura dello schermo dei siti di origine delle visite',
'info_question_vignettes_referer_oui' => 'Visualizzare le catture di schermo dei siti di origine delle visite',
'info_question_visiteur_ajout_document_forum' => 'Se si desidera autorizzare i visitatori ad allegare dei documenti (immagini, musiche, ecc.) ai propri messaggi nel forum, indicare qui sotto l\'elenco delle estensioni dei documenti autorizzati per i forum (per es.: gif, jpg, png, mp3).',
'info_question_visiteur_ajout_document_forum_format' => 'Se si desidera autorizzare tutti i tipi di documenti considerati affidabili da SPIP, mettere un asterisco. Per non autorizzare nulla, non indicare nulla.',
'info_qui_attribue_mot_cle' => 'Le parole chiave di questo gruppo possono essere attribuite da:',
'info_racine_site' => 'Root del sito',
'info_recharger_page' => 'Aggiorna questa pagina fra qualche istante.',
'info_recherche_auteur_a_affiner' => 'Troppi risultati per "@cherche_auteur@"; restringi la ricerca.',
'info_recherche_auteur_ok' => 'Molti redattori trovati per "@cherche_auteur@":',
'info_recherche_auteur_zero' => 'Nessun risultato per "@cherche_auteur@".',
'info_recommencer' => 'Ricomincia.',
'info_redacteur_1' => 'Redattori',
'info_redacteur_2' => 'avendo accesso allo spazio privato (<i>raccommandato</i>)',
'info_redacteurs' => 'Redattori',
'info_redaction_en_cours' => 'IN CORSO DI REDAZIONE',
'info_redirection' => 'Reindirizzamento',
'info_referencer_doc_distant' => 'Mettere in repertorio un documento su Internet:',
'info_refuses' => 'I tuoi articoli rifiutati',
'info_reglage_ldap' => 'Opzioni: <b>Parametri per l\'importazione LDAP</b>',
'info_renvoi_article' => '<b>Reindirizzamento.</b> Quest\'articolo rimanda alla pagina:',
'info_reserve_admin' => 'Solo gli amministratori possono modificare quest\'indirizzo.',
'info_restauration_sauvegarde' => 'Ripristino del salvataggio @archive@',
'info_restauration_sauvegarde_insert' => 'Inserimento di @archive@ nel database',
'info_restreindre_rubrique' => 'Limita la facolt&agrave; di gestione alla rubrica:',
'info_resultat_recherche' => 'Risultati della ricerca:',
'info_rubriques' => 'Rubriche',
'info_rubriques_02' => 'rubriche',
'info_rubriques_liees_mot' => 'Le rubriche collegate a questa parola chiave',
'info_rubriques_trouvees' => 'Rubriche trovate',
'info_rubriques_trouvees_dans_texte' => 'Rubriche trovate (ricerca nel testo)',
'info_sans_titre' => 'Senza titolo',
'info_sauvegarde' => 'Salvataggio',
'info_sauvegarde_articles' => 'Salva gli articoli',
'info_sauvegarde_articles_sites_ref' => 'Salva gli articoli dei siti citati',
'info_sauvegarde_auteurs' => 'Salva gli autori',
'info_sauvegarde_breves' => 'Salva le brevi',
'info_sauvegarde_documents' => 'Salva i documenti',
'info_sauvegarde_echouee' => 'Se il salvataggio &egrave; fallito (&laquo;Maximum execution time exceeded&raquo;),',
'info_sauvegarde_forums' => 'Salva i forum',
'info_sauvegarde_groupe_mots' => 'Salva i gruppi di parole',
'info_sauvegarde_messages' => 'Salva i messaggi',
'info_sauvegarde_mots_cles' => 'Salva le parole chiave',
'info_sauvegarde_petitions' => 'Salva le petizioni  ',
'info_sauvegarde_refers' => 'Salva i <em>referrer</em> (siti che fanno riferimento al tuo)',
'info_sauvegarde_reussi_01' => 'Salvataggio riuscito.',
'info_sauvegarde_reussi_02' => 'Il database &egrave; stato salvato in @archive@. Puoi ',
'info_sauvegarde_reussi_03' => 'tornare alla gestione',
'info_sauvegarde_reussi_04' => 'del tuo sito.',
'info_sauvegarde_rubrique_reussi' => 'Le tabelle della rubrica @titre@ sono state salvate in @archive@. &Egrave; possibile',
'info_sauvegarde_rubriques' => 'Salva le rubriche',
'info_sauvegarde_signatures' => 'Salva le adesioni alle petizioni',
'info_sauvegarde_sites_references' => 'Salva i siti in repertorio',
'info_sauvegarde_type_documents' => 'Salva i tipi di documento',
'info_sauvegarde_visites' => 'Salva le visite',
'info_selection_chemin_acces' => '<b>Seleziona</b> qui sotto il percorso d\'accesso nell\'elenco:',
'info_selection_un_seul_mot_cle' => '&Egrave; consentito selezionare <b>una sola parola chiave</b> alla volta in questo gruppo.',
'info_signatures' => 'firme',
'info_site' => 'Sito',
'info_site_2' => 'sito: ',
'info_site_min' => 'sito',
'info_site_propose' => 'Sito proposto il:',
'info_site_reference_2' => 'Sito repertoriato',
'info_site_syndique' => 'Questo &egrave; un sito in syndication...',
'info_site_valider' => 'Siti da convalidare',
'info_site_web' => 'SITO WEB:',
'info_sites' => 'siti',
'info_sites_lies_mot' => 'I siti in repertorio legati a questa parola chiave',
'info_sites_proxy' => 'Utilizza un proxy',
'info_sites_refuses' => 'I siti rifiutati',
'info_sites_trouves' => 'Siti trovati',
'info_sites_trouves_dans_texte' => 'Siti trovati (nel testo)',
'info_sous_titre' => 'Sottotitolo:',
'info_statut_administrateur' => 'Amministratore',
'info_statut_auteur' => 'Status di questo autore:',
'info_statut_auteur_a_confirmer' => 'Iscrizione da confermare',
'info_statut_auteur_autre' => 'Altro stato:',
'info_statut_efface' => 'Cancellato',
'info_statut_redacteur' => 'Redattore',
'info_statut_site_1' => 'Questo sito &egrave;:',
'info_statut_site_2' => 'Pubblicato',
'info_statut_site_3' => 'Proposto',
'info_statut_site_4' => 'Nel cestino',
'info_statut_utilisateurs_1' => 'Status predefinito degli utenti importati',
'info_statut_utilisateurs_2' => 'Scegli lo status da attribuire alle personne presenti nell\'elenco LDAP quando si collegano per la prima volta. Potrai poi modificare questa impostazione per ogni singolo autore.',
'info_suivi_activite' => 'Monitoraggio dell\'attivit&agrave; editoriale',
'info_supprimer_mot' => 'cancella&nbsp;questa&nbsp;parola',
'info_surtitre' => 'Occhiello:',
'info_syndication_integrale_1' => 'Il tuo sito propone dei file di  syndication (vedi &laquo;&nbsp;<a href="@url@">@titre@</a>&nbsp;&raquo;).',
'info_syndication_integrale_2' => 'Si desidera trasmettere gli articoli in versione integrale oppure in versione riassunta di un centinaio di caratteri?',
'info_table_prefix' => '&Egrave; possibile modificare il prefisso del nome delle tabelle del database (cosa indispensabile se si desidera installare pi&ugrave; siti usando il medesimo database). Questo prefisso si deve scrivere usando esclusivamente lettere minuscole, prive di accenti e senza alcuno spazio.',
'info_taille_maximale_images' => 'SPIP tester&agrave; la dimensione massima delle immagini che pu&ograve; manipolare (in milioni di pixel).<br /> Le immagini di dimensione maggiore non saranno ridotte.',
'info_taille_maximale_vignette' => 'Dimensione massima delle immagini create dal sistema:',
'info_terminer_installation' => 'Puoi ora terminare la procedura d\'installazione standard.',
'info_texte' => 'Testo',
'info_texte_explicatif' => 'Testo esplicativo',
'info_texte_long' => '(il testo &egrave; lungo: &egrave; quindi visualizzato in pi&ugrave; sezioni che verranno riunificate dopo la convalida)',
'info_texte_message' => 'Testo del messaggio:',
'info_texte_message_02' => 'Testo del messaggio',
'info_titre' => 'Titolo:',
'info_titre_mot_cle' => 'Nome o titolo della parola chiave',
'info_total' => 'totale: ',
'info_tous_articles_en_redaction' => 'Tutti gli articoli in corso di redazione',
'info_tous_articles_presents' => 'Tutti gli articoli pubblicati in questa rubrica',
'info_tous_articles_refuses' => 'Tutti gli articoli rifiutati',
'info_tous_les' => 'tutti i:',
'info_tous_redacteurs' => 'Annunci a tutti i redattori',
'info_tout_site' => 'Tutto il sito',
'info_tout_site2' => 'L\'articolo non &egrave; stato tradotto in questa lingua.',
'info_tout_site3' => 'L\'articolo &egrave; stato tradotto in questa lingua, ma sono state effettuate alcune modifiche all\'articolo di riferimento. La traduzione deve quindi essere aggiornata.',
'info_tout_site4' => 'L\'articolo &egrave; stato tradotto in questa lingua e la traduzione &egrave; aggiornata.',
'info_tout_site5' => 'Articolo originale.',
'info_tout_site6' => '<b>Attenzione:</b> solo gli articoli originali vengono visualizzati.
Le traduzioni sono associate all\'originale,
 in un colore che indica il loro stato:',
'info_travail_colaboratif' => 'Lavoro di collaborazione sugli articoli',
'info_un_article' => 'un articolo, ',
'info_un_mot' => 'Una parola sola alla volta',
'info_un_site' => 'un sito, ',
'info_une_breve' => 'una breve, ',
'info_une_rubrique' => 'una rubrica, ',
'info_une_rubrique_02' => '1 rubrica',
'info_url' => 'URL:',
'info_url_site' => 'URL DEL SITO:',
'info_urlref' => 'Link ipertestuale:',
'info_utilisation_spip' => 'Puoi ora cominciare ad utilizzare il sistema di pubblicazione assistita...',
'info_visites_par_mois' => 'Visualizzazione per mese:',
'info_visites_plus_populaires' => 'Pubblica le visite per <b>gli articoli pi&ugrave; popolari </b> e per <b>gli ultimi articoli pubblicati:</b>',
'info_visiteur_1' => 'Visitatori',
'info_visiteur_2' => 'del sito pubblico',
'info_visiteurs' => 'Visitatori',
'info_visiteurs_02' => 'Visitatori del sito pubblico',
'install_adresse_base_hebergeur' => 'Indirizzo del database attribuito dal provider',
'install_base_ok' => 'Il database @base@ &egrave; stato riconosciuto',
'install_echec_annonce' => 'L\'installazione potrebbe fallire oppure causare problemi di funzionalit&agrave; al sito...',
'install_extension_mbstring' => 'SPIP non funziona con:',
'install_extension_php_obligatoire' => 'SPIP esige l\'estensione php:',
'install_login_base_hebergeur' => 'Login di connessione attribuito dal provider',
'install_nom_base_hebergeur' => 'Nome del database attribuito dal provider:',
'install_pas_table' => 'Database attualmente senza tabelle',
'install_pass_base_hebergeur' => 'Password di connessione attribuito dal provider',
'install_php_version' => 'PHP versione @version@ insufficiente (minimo = @minimum@)',
'install_select_langue' => 'Seleziona una lingua e poi clicca sul bottone &laquo;&nbsp;Avanti&nbsp;&raquo; per lanciare la procedura di installazione.',
'install_select_type_db' => 'Indicare il tipo di database:',
'install_select_type_mysql' => 'MySQL',
'install_select_type_pg' => 'PostgreSQL',
'install_select_type_sqlite2' => 'SQLite 2',
'install_select_type_sqlite3' => 'SQLite 3',
'install_serveur_hebergeur' => 'Server del database attribuito dall\'hoster',
'install_table_prefix_hebergeur' => 'Prefisso della tabella attribuito dal provider:',
'install_tables_base' => 'Tabelle del database',
'install_types_db_connus' => 'SPIP pu&ograve; utilizzare <b>MySQL</b> (il pi&ugrave; diffuso), <b>PostgreSQL</b> e <b>SQLite</b>.',
'install_types_db_connus_avertissement' => 'Attenzione: numerosi plug-in funziano solamente con MySQL',
'intem_redacteur' => 'redattore',
'intitule_licence' => 'Licenza',
'item_accepter_inscriptions' => 'Accetta le iscrizioni',
'item_activer_forum_administrateur' => 'Attiva il forum degli amministratori',
'item_activer_messages_avertissement' => 'Attiva i messaggi d\'avvertimento',
'item_administrateur_2' => 'amministratore',
'item_afficher_calendrier' => 'Pubblica nel calendario',
'item_ajout_mots_cles' => 'Consenti l\'uso di parole chiave nei forum',
'item_autoriser_documents_joints' => 'Consenti di allegare documenti agli articoli',
'item_autoriser_documents_joints_rubriques' => 'Consenti di allegare documenti alle rubriche',
'item_autoriser_selectionner_date_en_ligne' => 'Permetti di modificare la data di ogni documento',
'item_autoriser_syndication_integrale' => 'Diffondere la versione integrale degli articoli nei file di syndication',
'item_bloquer_liens_syndiques' => 'Blocca i link in syndication per la convalida',
'item_breve_refusee' => 'NO - Breve rifiutata',
'item_breve_validee' => 'SI - Breve convalidata',
'item_choix_administrateurs' => 'gli amministratori',
'item_choix_generation_miniature' => 'Genera automaticamente le thumbnail delle immagini.',
'item_choix_non_generation_miniature' => 'Non creare le thumbnail delle immagini.',
'item_choix_redacteurs' => 'i redattori',
'item_choix_visiteurs' => 'i visitatori del sito pubblico',
'item_compresseur' => 'Attiva la compressione',
'item_config_forums_prive_global' => 'Attiva i forum dei redattori',
'item_config_forums_prive_objets' => 'Attiva questi forum',
'item_creer_fichiers_authent' => 'Crea i file .htpasswd',
'item_desactiver_forum_administrateur' => 'Disattiva il forum degli amministratori',
'item_gerer_annuaire_site_web' => 'Gestisci un repertorio di siti Web',
'item_gerer_statistiques' => 'Gestisci le statistiche',
'item_limiter_recherche' => 'Limita la ricerca alle informazioni contenute nel tuo sito',
'item_login' => 'Login',
'item_messagerie_agenda' => 'Attiva la messaggistica e l’agenda',
'item_mots_cles_association_articles' => 'agli articoli',
'item_mots_cles_association_breves' => 'alle brevi',
'item_mots_cles_association_rubriques' => 'alle rubriche',
'item_mots_cles_association_sites' => 'ai siti repertoriati o in syndication.',
'item_non' => 'No',
'item_non_accepter_inscriptions' => 'Non accettare le iscrizioni',
'item_non_activer_messages_avertissement' => 'Nessun messaggio d\'avvertimento',
'item_non_afficher_calendrier' => 'Non pubblicare nel calendario',
'item_non_ajout_mots_cles' => 'Non consentire l\'uso di parole chiave nei forum',
'item_non_autoriser_documents_joints' => 'Non consentire di allegare documenti agli articoli',
'item_non_autoriser_documents_joints_rubriques' => 'Non consentire di allegare documenti alle rubriche',
'item_non_autoriser_selectionner_date_en_ligne' => 'La data dei documenti &egrave; quella in cui sono stati aggiunti al sito.',
'item_non_autoriser_syndication_integrale' => 'Diffondere solo un riassunto',
'item_non_bloquer_liens_syndiques' => 'Non bloccare i link provenienti da una syndication',
'item_non_compresseur' => 'Disattiva la compressione',
'item_non_config_forums_prive_global' => 'Disattiva i forum dei redattori',
'item_non_config_forums_prive_objets' => 'Disattiva questi forum',
'item_non_creer_fichiers_authent' => 'Non creare questi file',
'item_non_gerer_annuaire_site_web' => 'Disattiva il repertorio di siti Web',
'item_non_gerer_statistiques' => 'Non gestire le statistiche',
'item_non_limiter_recherche' => 'Estendi la ricerca al contenuto dei siti in syndication',
'item_non_messagerie_agenda' => 'Disattiva la messaggistica e l’agenda',
'item_non_publier_articles' => 'Non pubblicare gli articoli prima della data impostata.',
'item_non_utiliser_breves' => 'Non utilizzare le brevi',
'item_non_utiliser_config_groupe_mots_cles' => 'Non utilizzare la configurazione avanzata dei gruppi di parole chiave',
'item_non_utiliser_moteur_recherche' => 'Non utilizzare il motore di ricerca',
'item_non_utiliser_mots_cles' => 'Non utilizzare le parole chiave',
'item_non_utiliser_syndication' => 'Non attivare la syndication automatica',
'item_nouvel_auteur' => 'Nuovo autore',
'item_nouvelle_breve' => 'Nuova breve',
'item_nouvelle_rubrique' => 'Nuova rubrica',
'item_oui' => 'Si',
'item_publier_articles' => 'Pubblica gli articoli indipendentemente dalla data impostata.',
'item_reponse_article' => 'Risposta all\'articolo ',
'item_utiliser_breves' => 'Utilizza le brevi',
'item_utiliser_config_groupe_mots_cles' => 'Utilizza la configurazione avanzata dei gruppi di parole chiave',
'item_utiliser_moteur_recherche' => 'Utilizza il motore di ricerca',
'item_utiliser_mots_cles' => 'Utilizza le parole chiave',
'item_utiliser_syndication' => 'Attiva la syndication automatica',
'item_visiteur' => 'visitatore',

// J
'jour_non_connu_nc' => 'n.c.',

// L
'lien_ajout_destinataire' => 'Aggiungi il destinatario',
'lien_ajouter_auteur' => 'Aggiungi questo autore',
'lien_ajouter_participant' => 'Aggiungi un partecipante',
'lien_email' => 'email',
'lien_forum_public' => 'Gestisci il forum pubblico di quest\'articolo',
'lien_mise_a_jour_syndication' => 'Aggiorna adesso',
'lien_nom_site' => 'NOME DEL SITO:',
'lien_nouvelle_recuperation' => 'Tenta nuovamente di ripristinare i dati',
'lien_reponse_article' => 'Risposta all\'articolo',
'lien_reponse_breve' => 'Risposta alla breve',
'lien_reponse_breve_2' => 'Risposta alla breve',
'lien_reponse_rubrique' => 'Risposta alla rubrica',
'lien_reponse_site_reference' => 'Risposta al sito repertoriato:',
'lien_retirer_auteur' => 'Rimuovere l\'autore',
'lien_retrait_particpant' => 'rimuovere questo partecipante',
'lien_site' => 'sito',
'lien_supprimer_rubrique' => 'elimina la rubrica',
'lien_tout_deplier' => 'Espandi',
'lien_tout_replier' => 'Richiudi',
'lien_tout_supprimer' => 'Eliminare tutto',
'lien_trier_nom' => 'Ordina per nome',
'lien_trier_nombre_articles' => 'Ordina per numero di articoli',
'lien_trier_statut' => 'Ordina per status',
'lien_voir_en_ligne' => 'VEDI ON LINE:',
'logo_article' => 'LOGO DELL\'ARTICOLO',
'logo_auteur' => 'LOGO DELL\'AUTORE',
'logo_breve' => 'LOGO DELLA BREVE',
'logo_mot_cle' => 'LOGO DELLA PAROLA CHIAVE',
'logo_rubrique' => 'LOGO DELLA RUBRICA',
'logo_site' => 'LOGO DI QUESTO SITO ',
'logo_standard_rubrique' => 'LOGO STANDARD DELLE RUBRICHE',
'logo_survol' => 'LOGO ROLLOVER',

// M
'menu_aide_installation_choix_base' => 'Scegliere il database',
'module_fichier_langue' => 'File lingua',
'module_raccourci' => 'Scorciatoia',
'module_texte_affiche' => 'Testo visualizzato',
'module_texte_explicatif' => '&Egrave; possibile inserire le scorciatoie nel modello di layout del proprio sito pubblico. Queste verranno tradotte automaticamente nelle diverse lingue (se esiste gi&agrave; un file lingua).',
'module_texte_traduction' => 'Il file lingua &laquo;@module@&raquo; &egrave; disponibile in:',
'mois_non_connu' => 'sconosciuto',

// N
'nouvelles_versions' => 'Una nuova versione di SPIP &egrave; disponibile',

// O
'onglet_contenu' => 'Contenuto',
'onglet_declarer_une_autre_base' => 'Dichiarare un altro database',
'onglet_discuter' => 'Discuti',
'onglet_documents' => 'Documenti',
'onglet_interactivite' => 'Interattivit&agrave;',
'onglet_proprietes' => 'Propriet&agrave;',
'onglet_repartition_actuelle' => 'attualmente',
'onglet_sous_rubriques' => 'Sotto-rubriche',
'ortho_ajouter_ce_mot' => 'Aggiungere questa parola al dizionario',
'ortho_aucune_suggestion' => 'Nessun suggerimento per questa parola.',
'ortho_avis_privacy' => 'SPIP ha un controllo ortografico integrato. Prima di attivare questa funzionalit&agrave;, leggere attentamente quanto segue:',
'ortho_avis_privacy2' => 'Per verificare l\'ortografia di un testo, il sito invier&agrave; la lista di parole da controllare a uno dei "server ortografici" esterni messi a disposizione al pubblico dai membri della comunit&agrave; SPIP. Le parole sono inviate in ordine casuale per rispettare la propriet&agrave; intellettuale degli autori. &Egrave; consigliabile disattivare tale funzionalit&agrave; se i testi trattati nel sito sono ritenuti troppo confidenziali (e magari si eviti di pubblicarli sul web...).',
'ortho_ce_mot_connu' => 'Questa parola fa parte del dizionario del sito.',
'ortho_dico_absent' => 'Nessun dizionario disponibile per questa lingua',
'ortho_mode_demploi' => 'Le parole non riconosciute sono sottolineate in rosso. &Egrave; possibile cliccare su ogni parola per visualizzare eventuali suggerimenti per la correzione.',
'ortho_mots_a_corriger' => 'parole da correggere',
'ortho_orthographe' => 'Ortografia',
'ortho_supprimer_ce_mot' => 'Eliminare questa parola dal dizionario',
'ortho_trop_de_fautes' => 'Attenzione: il testo contiene troppi errori, non &egrave; stato fornito alcun suggerimento di correzione per evitare di sovraccaricare il sistema.',
'ortho_verif_impossible' => 'Il sistema non pu&ograve; controllare l\'ortografia di questo testo.',
'ortho_verifier' => 'Controllare l\'ortografia',

// P
'page_pas_proxy' => 'Questa pagina non deve passare attraverso il proxy',
'pas_de_proxy_pour' => 'Se necessario, indicare i server o i domini per i quali non si deve applicare questo proxy (per esempio: @exemple@)',
'plugin_charge_paquet' => 'Caricamento del pacchetto @name@',
'plugin_charger' => 'Download',
'plugin_erreur_charger' => 'errore: impossibile caricare @zip@',
'plugin_erreur_droit1' => 'La cartella <code>@dest@</code> non ha i permessi di scrittura.',
'plugin_erreur_droit2' => 'Verificare i diritti su questa cartella (e, se necessario, crearla), o installare i file tramite FTP.',
'plugin_erreur_zip' => 'fallimento pclzip: errore @status@',
'plugin_etat_developpement' => 'in corso di sviluppo',
'plugin_etat_experimental' => 'sperimentale',
'plugin_etat_stable' => 'stabile',
'plugin_etat_test' => 'in prova',
'plugin_impossible_activer' => 'Impossibile attivare il plug-in @plugin@',
'plugin_info_automatique1' => 'Se si desidera autorizzare l\'installazione automatica dei plug-in &egrave; necessario: ',
'plugin_info_automatique1_lib' => 'If you wish to authorise the automatic installation of this library, please:', # NEW
'plugin_info_automatique2' => 'creare una cartella <code>@rep@</code>;',
'plugin_info_automatique3' => 'verificare che il server sia autorizzato a scrivere in questa cartella.',
'plugin_info_automatique_creer' => 'da creare alla radice del sito.',
'plugin_info_automatique_exemples' => 'esempi:',
'plugin_info_automatique_ftp' => '&Egrave; possibile installare plug-in tramite FTP, nella cartella <tt>@rep@</tt>',
'plugin_info_automatique_lib' => 'Alcuni plug-in richiedono anche di poter trasferire dei file nella cartella <code>lib/</code>, da creare (se necessario) alla radice del sito.',
'plugin_info_automatique_liste' => 'Gli elenchi dei plug-in:',
'plugin_info_automatique_liste_officielle' => 'i plug-in ufficiali',
'plugin_info_automatique_liste_update' => 'Aggiornare gli elenchi',
'plugin_info_automatique_ou' => 'oppure...',
'plugin_info_automatique_select' => 'Selezionata un plug-in qui sotto: SPIP lo scaricher&agrave; e lo installer&agrave; nella cartella <code>@rep@</code>; se questo plug-in &egrave; gi&agrave; presente verr&agrave; aggiornato.',
'plugin_info_extension_1' => 'The extensions below are loaded and active in the @extensions@ directory.', # NEW
'plugin_info_extension_2' => 'They cannot be uninstalled.', # NEW
'plugin_info_telecharger' => 'da scaricare da @url@ e da installare in @rep@',
'plugin_librairies_installees' => 'Librerie installate',
'plugin_necessite_lib' => 'Questo plug-in richiede la libreria @lib@',
'plugin_necessite_plugin' => 'Necessita il plug-in @plugin@ con almeno la versione @version@.',
'plugin_necessite_spip' => 'Necessita SPIP con almeno la versione @version@.',
'plugin_source' => 'origine:&nbsp;',
'plugin_titre_automatique' => 'Installazione automatica',
'plugin_titre_automatique_ajouter' => 'Aggiungere dei plug-in',
'plugin_titre_installation' => 'Installation of the @plugin@ plugin', # NEW
'plugin_zip_active' => 'Continuare per attivarlo',
'plugin_zip_adresse' => 'indicate qui sotto l\'indirizzo di un file zip del plug-in da scaricare, oppure l\'indirizzo di un elenco di plug-in.',
'plugin_zip_adresse_champ' => 'Indirizzo del plug-in o dell\'elenco&nbsp;',
'plugin_zip_content' => 'Esso contiene i file seguenti (@taille@),<br />pronti per essere installati nella cartella <code>@rep@</code>',
'plugin_zip_installe_finie' => 'Il file @zip@ &egrave; stato decompresso e installato.',
'plugin_zip_installe_rep_finie' => 'Il file @zip@ &egrave; stato decompresso e installato nella cartella @rep@',
'plugin_zip_installer' => 'Ora &egrave; possibile installarlo.',
'plugin_zip_telecharge' => 'Il file @zip@ &egrave; stato scaricato',
'plugins_actif_aucun' => 'No plugin is active.', # NEW
'plugins_actif_un' => 'One plugin active', # NEW
'plugins_actifs' => '@count@ plug-in attivati.',
'plugins_actifs_liste' => 'Active plugins', # NEW
'plugins_compte' => '@count@ plug-in',
'plugins_disponible_un' => 'One plugin available', # NEW
'plugins_disponibles' => '@count@ plug-in disponibili.',
'plugins_erreur' => 'Errore nei plug-in: @plugins@',
'plugins_liste' => 'Elenco dei plugin',
'plugins_liste_extensions' => 'Extensions', # NEW
'plugins_recents' => 'Recent plugins', # NEW
'plugins_vue_hierarchie' => 'Struttura gerarchica',
'plugins_vue_liste' => 'Elenco',
'protocole_ldap' => 'Versione del protocollo:',

// R
'repertoire_plugins' => 'Cartella:',

// S
'sans_heure' => 'ora mancante',
'sauvegarde_fusionner' => 'Unire il database attuale con la copia di backup',
'sauvegarde_fusionner_depublier' => 'Depubblicare gli oggetti fusi',
'sauvegarde_url_origine' => 'Eventualmente, URL del sito di origine:',
'statut_admin_restreint' => '(ammin. parziale)',
'syndic_choix_moderation' => 'Come comportarsi con i prossimi link provenienti da questo sito?',
'syndic_choix_oublier' => 'Come comportarsi con i link che non compaiono pi&ugrave; nel file di syndication?',
'syndic_choix_resume' => 'Alcuni siti diffondono il testo completo degli articoli. Nel caso esso sia disponibile desiderate metterlo in syndication:',
'syndic_lien_obsolete' => 'link non pi&ugrave; valido',
'syndic_option_miroir' => 'bloccarli automaticamente',
'syndic_option_oubli' => 'cancellarli (dopo @mois@&nbsp;mesi)',
'syndic_option_resume_non' => 'il contenuto completo degli articoli(in formato HTML)',
'syndic_option_resume_oui' => 'un semplice riassunto (in formato testo)',
'syndic_options' => 'Opzioni per la syndication:',

// T
'taille_cache_image' => 'Le immagini elaborate automaticamente da SPIP (icone dei documenti, titoli in formato grafico, funzioni matematiche in formato TeX...) occupano nella cartella @dir@ in tutto @taille@.',
'taille_cache_infinie' => 'Questo sito non prevede limiti alle dimensioni della cartella della cache.',
'taille_cache_maxi' => 'SPIP tenta di limitare le dimensioni della cartella della cache di questo sito a circa <b>@octets@</b> di dati.',
'taille_cache_octets' => 'La cartella della cache occupa attualmente @octets@ su disco.',
'taille_cache_vide' => 'La cache &egrave; vuota.',
'taille_repertoire_cache' => 'Dimensioni della cartella di cache',
'text_article_propose_publication' => 'Articolo proposto per la pubblicazione. ',
'text_article_propose_publication_forum' => 'Non esitare ad esprimere il tuo punto di vista nel forum di questo articolo (a fondo pagina).',
'texte_acces_ldap_anonyme_1' => 'Alcuni server LDAP non consentono accessi anonimi. In questo caso si deve specificare un identificatore d\'accesso iniziale al fine di poter poi ricercare delle informazioni nell\'elenco. Nella maggior parte dei casi tuttavia, i campi seguenti potranno essere lasciati vuoti.',
'texte_admin_effacer_01' => 'Questo commando cancella <i>tutto</i> il contenuto del database,
 compresi <i>tutti</i> i login dei redattori e degli amministratori. Dopo averlo eseguito, dovrai riavviare la procedura di installazione per ricreare un nuovo database e un primo ID amministrativo.',
'texte_admin_effacer_stats' => 'Questo comando cancella tutti i dati collegati alle statistiche delle visite al sito, comprese la popolarit&agrave; degli articoli.',
'texte_admin_tech_01' => 'Questa opzione permette di salvare il contenuto del database in un file che sar&agrave; conservato nella cartella @dossier@.
Non dimenticare di recuperare integralmente anche la cartella @img@, che contiene le immagini e i documenti utilizzati negli articoli e nelle rubriche.',
'texte_admin_tech_02' => 'Attenzione: questo backup potr&agrave; essere ripristinato SOLO in un sito installato con la stessa versione di SPIP.Soprattutto, &egrave; sbagliato &laquo;&nbsp;svuotare il database&nbsp;&raquo; pensando di ripristinare questo backup dopo aver aggiornato la versione di SPIP...
Per maggiori informazioni consulta <a href="@spipnet@">la documentazione di SPIP</a>.',
'texte_admin_tech_03' => 'Puoi scegliere di salvare il file in forma compressa, al fine di ridurre
i tempi di trasferimento in rete e di risparmiare dello spazio su disco.',
'texte_admin_tech_04' => 'Al fine di una fusione con un altro database, &egrave; possibile limitare il salvataggio alla rubrica: ',
'texte_adresse_annuaire_1' => '(Se la rubrica &egrave; installata nella stessa macchina di questo sito, dovrai probabilmente inserire "localhost".)',
'texte_ajout_auteur' => 'Il seguente autore &egrave; stato aggiunto all\'articolo:',
'texte_annuaire_ldap_1' => 'Se hai accesso ad una rubrica (LDAP), puoi utilizzarla per importare automaticamente degli utenti sotto SPIP.',
'texte_article_statut' => 'Questo articolo &egrave;:',
'texte_article_virtuel' => 'Articolo virtuale',
'texte_article_virtuel_reference' => '<b>Articolo virtuale:</b> articolo citato nel tuo sito SPIP, ma reindrizzato verso un\'altro URL. Per eliminare il reindirizzamento, cancella l\'URL qui sopra.',
'texte_aucun_resultat_auteur' => 'Nessun risultato per "@cherche_auteur@"',
'texte_auteur_messagerie' => 'Questo sito pu&ograve; costantemente visualizzare la lista dei redattori collegati, permettendo lo scambio di messaggi in tempo reale. Si pu&ograve; per&ograve; decidere di non comparire in questo elenco (rendendosi quindi &laquo;invisibili&raquo; agli altri utenti).',
'texte_auteur_messagerie_1' => 'Questo sito permette lo scambio di messaggi e la costituzione di forum di discussione privati tra i partecipanti al sito. Puoi per&ograve; decidere di non partecipare a questi scambi.',
'texte_auteurs' => 'GLI AUTORI',
'texte_breves' => 'Le brevi sono dei testi corti e semplici che consentono
di mettere on line rapidamente delle news di attualit&agrave;,
di gestire una rassegna stampa o un calendario di eventi, ecc.',
'texte_choix_base_1' => 'Scegli il database:',
'texte_choix_base_2' => 'Il server SQL contiene diversi database.',
'texte_choix_base_3' => '<b>Seleziona</b> quello che &egrave; stato attribuito al tuo dominio:',
'texte_choix_table_prefix' => 'Prefisso delle tabelle:',
'texte_commande_vider_tables_indexation' => 'Utilizza questo comando per svuotare le tabelle d\'incidizzazione utilizzate
dal motore di ricerca integrato di SPIP. Ci&ograve; permetter&agrave;
di guadagnare spazio sul disco.',
'texte_comment_lire_tableau' => 'Il posizionamento dell\'articolo,
nella classifica per popolarit&agrave;, &egrave; indicato qui
sopra. La popolarit&agrave; dell\'articolo (una stima del
numero di visite quotidiane che ricever&agrave; rimanendo costante il ritmo attuale di
consultazione) e il numero di visite ricevute dall\'inizio,
sono visualizzati nel commento che appare
quando si passa con il mouse sopra al titolo.',
'texte_compacter_avertissement' => 'Fare attenzione a non attivare queste opzioni durante la fase di sviluppo del sito: gli elementi compressi sono completamente illeggibili.',
'texte_compacter_script_css' => 'SPIP pu&ograve; comprimere gli script javascript e i fogli di stile CSS, per registrarli nei file statici; ci&ograve; accelera la visualizzazione del sito.',
'texte_compresse_ou_non' => '(pu&ograve; essere compresso o meno)',
'texte_compresseur_page' => 'SPIP pu&ograve; comprimere automaticamente tutte le pagine che invia ai
visitatori del sito. Questa impostazione permette di ottimizzare la banda passante (il
sito &egrave; pi&ugrave; rapido in una connessione a bassa velocit&agrave;), ma
richiede una maggiore potenza del server.',
'texte_compte_element' => '@count@ elemento',
'texte_compte_elements' => '@count@ elementi',
'texte_config_groupe_mots_cles' => 'Vuoi attivare la configurazione avanzata delle parole chiave,
indicando per esempio che si pu&ograve; selezionare una parola unica per gruppo o che un gruppo &egrave; importante, ecc.?',
'texte_conflit_edition_correction' => 'Controllare qui sotto le differenze tra le due versioni del testo; &egrave; possibile anche copiare le modifiche e poi ricominciare.',
'texte_connexion_mysql' => 'Consulta le informazioni fornite dal tuo hoster: devi poterci trovare i codici di collegamento alla base di dati.',
'texte_contenu_article' => 'Contenuto dell\'articolo in poche parole (<em>abstract</em>)',
'texte_contenu_articles' => 'A seconda del modello di presentazione adottato per il sito, puoi decidere
che alcuni elementi degli articoli siano utilizzati oppure no.
Serviti dell\'elenco qui sotto per indicare quali elementi rendere disponibili.',
'texte_crash_base' => 'Se il database &egrave; stato danneggiato, puoi tentare un ripristino automatico.',
'texte_creer_rubrique' => 'Prima di poter scrivere degli articoli,<br /> devi creare una rubrica.',
'texte_date_creation_article' => 'DATA DI CREAZIONE DELL\'ARTICOLO:',
'texte_date_publication_anterieure' => 'DATA DI REDAZIONE ANTERIORE',
'texte_date_publication_anterieure_nonaffichee' => 'Non visualizzare la data di redazione anteriore.',
'texte_date_publication_article' => 'DATA DI PUBBLICAZIONE:',
'texte_descriptif_petition' => 'Descrizione della petizione',
'texte_descriptif_rapide' => 'Descrizione rapida',
'texte_documents_joints' => '&Egrave; possibile autorizzare l\'aggiunta di documenti (file di testo, fogli elettronici, immagini, file multimediali, ecc.) agli articoli e/o alle rubriche. Questi file possono poi essere richiamati nel testo dell\'articolo, o visualizzati separatamente.', # MODIF
'texte_documents_joints_2' => 'Questa impostazione non impedisce l\'inserimento diretto di immagini negli articoli.',
'texte_effacer_base' => 'Cancella il database SPIP',
'texte_effacer_donnees_indexation' => 'Cancella i dati d\'indicizzazione',
'texte_effacer_statistiques' => 'Cancellare le statistiche',
'texte_en_cours_validation' => 'Gli articoli e le brevi elencati qui sotto sono proposti per la pubblicazione. ',
'texte_en_cours_validation_forum' => 'Non esitare ad esprimere il tuo punto di vista utilizzando i forum ad essi dedicati.',
'texte_enrichir_mise_a_jour' => 'Puoi arricchire la formattazione del testo utilizzando le &laquo;scorciatoie tipografiche&raquo;',
'texte_fichier_authent' => '<b>SPIP deve creare i file speciali <tt>.htpasswd</tt>
e <tt>.htpasswd-admin</tt> nella cartella @dossier@?</b><p>
 Questi file possono servire a limitare l\'accesso agli autori
e agli amministratori in particolari aree del sito
(per esempio, per un programma esterno di statistiche).</p><p>
Se ci&ograve; non &egrave; necessario, lasciare quest\'opzione
al suo valore predefinito (nessuna creazione 
di file).</p>', # MODIF
'texte_informations_personnelles_1' => 'Il sistema creer&agrave; un tuo accesso personalizzato al sito.',
'texte_informations_personnelles_2' => '(Nota: se si tratta di una reinstallazione, e il tuo accesso funziona ancora, puoi ',
'texte_introductif_article' => 'Testo introduttivo dell\'articolo',
'texte_jeu_caractere' => 'Si consiglia di utilizzare sul proprio sito l\'alfabeto universale (<tt>utf-8</tt>): esso permette di visualizzare i testi in tutte le lingue e non pone problemi di compatibilit&agrave; con i browser moderni.',
'texte_jeu_caractere_2' => 'Attenzione: questa impostazione non causa la conversione dei testi gi&agrave; registrati nel database.',
'texte_jeu_caractere_3' => 'Il tuo sito usa attualmente il set di caratteri:',
'texte_jeu_caractere_4' => 'Se ci&ograve; non corrisponde alla realt&agrave; dei propri dati (a causa, per esempio, di un ripristino del database), o se  <em>si avvia il sito</em> e si desidera partire con un altro set di caratteri &egrave; necessario indicare quest\'ultimo qui:',
'texte_jeu_caractere_conversion' => 'Nota: &egrave; possibile decidere di convertire una volta per tutte tutti i testi del sito (articoli, brevi, forum, ecc.) nell\'alfabeto <tt>utf-8</tt>, andando sulla <a href="@url@">pagina di conversione in utf-8</a>.',
'texte_lien_hypertexte' => '(Se il tuo messaggio si riferisce ad un articolo pubblicato sul Web, o ad una pagina che fornisce informazioni supplementari, indica il titolo della pagina e il suo indirizzo URL.)',
'texte_liens_sites_syndiques' => 'I link provenienti dai siti in syndication
possono essere bloccati a priori; l\'impostazione
qui sotto indica i criteri predefiniti dei siti in syndication.
Sar&agrave; comunque possibile sbloccare singolarmente ogni link,
o scegliere di bloccare i link di ogni singolo sito.',
'texte_login_ldap_1' => '(Lascia vuoto per un accesso anonimo, o inserisci il percorso completo, per esempio &laquo;<tt>uid=rossi, ou=users, dc=mio-dominio, dc=com</tt>&nbsp;&raquo;.)',
'texte_login_precaution' => 'Attenzione! Questo &egrave; l\'ID con il quale sei attualmente collegato.
Utilizza questo modulo con cognizione di causa...',
'texte_message_edit' => 'Attenzione: questo messaggio pu&ograve; essere modificato da tutti gli amministratori del sito, ed &egrave; visibile da tutti i redattori. Utilizza gli annunci solo per esporre degli eventi importanti per la vita del sito.',
'texte_messagerie_agenda' => 'La messageria permette ai redattori del sito di comunicare tra loro in maniera diretta nell\'area riservata. Essa &egrave; associata a una agenda.',
'texte_messages_publics' => 'Messaggi pubblici dell\'articolo:',
'texte_mise_a_niveau_base_1' => 'Hai aggiornato i file SPIP.
Adesso &egrave; necessario aggiornare il database.',
'texte_modifier_article' => 'Modifica l\'articolo:',
'texte_moteur_recherche_active' => '<b>Il motore di ricerca &egrave; attivato.</b> Utilizza questo commando
se vuoi procedere a una reindicizzazione rapida (dopo il ripristino
di un salvataggio, per esempio). Nota bene: i documenti modificati in modo standard (con l\'interfaccia di SPIP) sono automaticamente
reindicizzati. Questo commando, quindi, &egrave; utile solo in casi eccezionali.',
'texte_moteur_recherche_non_active' => 'Il motore di ricerca non &egrave; attivato.',
'texte_mots_cles' => 'Le parole chiave permettono di creare dei link tematici tra gli articoli
indipendentemente dal posto che occupano nelle diverse rubriche.
Si pu&ograve; quindi arricchire la navigazione del sito, o utilizzare queste propriet&agrave;
per personalizzare la presentazione degli articoli nei tuoi modelli di layout.',
'texte_mots_cles_dans_forum' => 'Vuoi consentire ai visitatori di selezionare delle parole chiave nei forum pubblici? (Attenzione: questa opzione &egrave; relativamente complessa da gestire in modo corretto.)',
'texte_multilinguisme' => 'Se desideri gestire gli articoli in diverse lingue, con un sistema di navigazione complesso, &egrave; possibile aggiungere un menu di selezione della lingua negli articoli e/o nelle rubriche, in funzione della struttura del sito.',
'texte_multilinguisme_trad' => '&Egrave; anche possibile attivare un sistema di gestione dei link fra le diverse traduzioni di un articolo.',
'texte_non_compresse' => '<i>non compresso</i> (il tuo server non supporta questa funzionalit&agrave;)',
'texte_non_fonction_referencement' => 'Puoi non utilizzare questa funzione automatica, e indicare direttamente gli elementi riguardanti il sito...',
'texte_nouveau_message' => 'Nuovo messaggio',
'texte_nouveau_mot' => 'Nuova parola',
'texte_nouvelle_version_spip_1' => 'Hai installato una nuova versione di SPIP.',
'texte_nouvelle_version_spip_2' => 'Questa nuova versione necessita un aggiornamento pi&ugrave; radicale del solito. Se sei il webmaster del sito, cancella il file @connect@ e riprendi l\'installazione al fine di aggiornare i parametri di connessione al database.<p> (NB: se hai dimenticato i parametri di connessione, rileggi il file @connect@ prima di cancellarlo...)</p>', # MODIF
'texte_operation_echec' => 'Torna alla pagina precedente, seleziona un altro database o creane uno nuovo. Verifica le informazioni fornite dal tuo hoster.',
'texte_plus_trois_car' => 'pi&ugrave; di tre caratteri',
'texte_plusieurs_articles' => 'Diversi autori trovati per "@cherche_auteur@":',
'texte_port_annuaire' => '(Il valore predefinito &egrave; in genere quello adatto.)',
'texte_presente_plugin' => 'Questa pagina elenca i plugin disponibili sul sito. &Egrave; possibile attivare i plugin necessari selezionando la casella corrispondente.',
'texte_proposer_publication' => 'Quando l\'articolo &egrave; completo,<br /> puoi proporne la pubblicazione.',
'texte_proxy' => 'In alcuni casi (intranet, reti protette...), i siti distanti (documetazione di SPIP, siti in syndication, ecc.) sono accessibili unicamente attraverso un <i>proxy HTTP</i>. In questo caso, va indicato l\'indirizzo del server nella forma @proxy_en_cours@. In genere questa casella va lasciata vuota.',
'texte_publication_articles_post_dates' => 'Come si deve comportare SPIP quando gli articoli hanno
una data di pubblicazione impostata nel futuro?',
'texte_rappel_selection_champs' => '[Non dimenticare di impostare correttamente questo campo]',
'texte_recalcul_page' => 'Se vuoi rigenerare
una sola pagina, utilizza piuttosto lo spazio pubblico e clicca sul pulsante &laquo;rigenera&raquo;.',
'texte_recapitiule_liste_documents' => 'Questa pagina mostra l\'elenco dei documenti allegati alle rubriche. Per modificare le informazioni di un documento, seguire il link verso la relativa pagina di rubrica.',
'texte_recuperer_base' => 'Ripara il database',
'texte_reference_mais_redirige' => 'articolo catalogato nel tuo sito SPIP, ma con reindirizzamento verso un altro URL.',
'texte_referencement_automatique' => '<b>Inserimento automatizzato in repertorio</b><br />&Egrave; possibile repertoriare rapidamente un sito Web indicandone qui sotto l\'indirizzo URL, o l\'indirizzo del file di syndication. SPIP recuperer&agrave; automaticamente le informazioni riguardanti il sito (titolo, descrizione...).',
'texte_referencement_automatique_verifier' => 'Controllare le informazioni fornite da <tt>@url@</tt> prima di registrare.',
'texte_requetes_echouent' => '<b>Quando alcune query SQL falliscono
ripetutamente e senza un chiaro motivo, &egrave; possibile
che sia per colpa del database stesso.</b><p>
Il server SQL dispone di una funzione di ripristino delle tabelle
danneggiate inavvertitamente. &Egrave; possibile tentare il ripristino;
in caso di errore, conservare una copia del messaggio visualizzato,
contenente forse delle informazioni preziose...</p><p>
Se il problema persiste, contattare il proprio fornitore di hosting.</p>', # MODIF
'texte_restaurer_base' => 'Ripristina un backup del database',
'texte_restaurer_sauvegarde' => 'Quest\'opzione permette il ripristino di un backup del database.
Il file di salvataggio deve trovarsi nella cartella @dossier@.
Attenzione: <b>le modifiche o la perdita eventuale di dati sono irreversibili.</b>',
'texte_sauvegarde' => 'Salva il contenuto del database',
'texte_sauvegarde_base' => 'Salva il database',
'texte_sauvegarde_compressee' => 'Il salvataggio avverr&agrave; nel file non compresso @fichier@.',
'texte_selection_langue_principale' => 'Puoi selezionare qui sotto la &laquo;lingua predefinita&raquo; del sito. Questa scelta non obbliga - fortunatamente! - a scrivere gli articoli nella stessa lingua, ma permette di determinare:
<ul><li> il formato di default delle date sul sito pubblico;</li>
<li> la tipologia di motore tipografico che SPIP deve utilizzare per la resa del testo;</li>
<li> la lingua utilizzata nelle finestre di dialogo del sito pubblico;</li>
<li> la lingua di default nell\'area riservata all\'amministrazione.</li></ul>',
'texte_signification' => 'Le barre pi&ugrave; scure rappresentano le entrate accumulate (per il totale delle sottorubriche), le barre pi&ugrave; chiare il numero di visite per ogni rubrica.',
'texte_sous_titre' => 'Sottotitolo',
'texte_statistiques_visites' => '(barre scure:  domenica / curve scure: evoluzione della media)',
'texte_statut_attente_validation' => 'in attesa di convalida',
'texte_statut_publies' => 'pubblicato on line',
'texte_statut_refuses' => 'rifiutati',
'texte_suppression_fichiers' => 'Utilizza questo commando per cancellare tutti i file presenti nella
cache di SPIP. Ci&ograve; permette ad esempio di forzare la rigenerazione di tutte le pagine se hai fatto delle importanti modifiche di grafica o di struttura del sito.',
'texte_sur_titre' => 'Occhiello',
'texte_syndication' => 'Quando un sito Web lo permette, &egrave; possibile recuperarne automaticamente
la lista delle novit&agrave;. A tal fine &egrave; necessario attivare la syndication.

<blockquote><i>Alcuni provider disattivano questa funzionalit&agrave;; 
in questo caso, non potrai utilizzare la syndication del contenuto
a partire dal tuo sito.</i></blockquote>',
'texte_table_ok' => ': questa tabella &egrave; OK.',
'texte_tables_indexation_vides' => 'Le tabelle d\'indicizzazione del motore sono vuote.',
'texte_tentative_recuperation' => 'Tentativo di ripristino',
'texte_tenter_reparation' => 'Tenta un ripristino del database',
'texte_test_proxy' => 'Per fare una prova di questo proxy, indicare qui l\'indirizzo
di un sito Web da testare.',
'texte_titre_02' => 'Titolo:',
'texte_titre_obligatoire' => '<b>Titolo</b> [Obbligatorio]',
'texte_travail_article' => '@nom_auteur_modif@ ha lavorato su questo articolo @date_diff@ minuti fa',
'texte_travail_collaboratif' => 'Se diversi autori lavorano spesso sullo stesso articolo,
il sistema pu&ograve; segnalare gli articoli &laquo;aperti&raquo;
di recente al fine di evitare modifiche simultanee.
Questa opzione &egrave; disattivata di default
per evitare di generare messaggi d\'avvertimento intempestivi.',
'texte_trop_resultats_auteurs' => 'Troppi risultati per "@cherche_auteur@"; restringi la ricerca.',
'texte_type_urls' => '&Egrave; possibile scegliere qui sotto il modo di elaborazione dell\'indirizzo delle pagine.',
'texte_type_urls_attention' => 'Attenzione: questa impostazione funziona solamente se il file @htaccess@ &egrave; installato correttamente alla radice del sito.',
'texte_unpack' => 'scarica l\'ultima versione',
'texte_utilisation_moteur_syndiques' => 'Quando utilizzi il motore di ricerca integrato di SPIP,
puoi effettuare le ricerche sui siti e
gli articoli in syndication
in due modalit&agrave; diverse. <br />- La pi&ugrave; semplice
consiste nel ricercare solo nei titoli e nelle descrizioni degli articoli.<br />-
Un altro metodo, molto pi&ugrave; potente, consente
a SPIP di cercare anche nel testo degli articoli in syndication.
Se inserisci un sito nel repertorio, SPIP effettuer&agrave; la ricerca anche nel testo del sito stesso.',
'texte_utilisation_moteur_syndiques_2' => 'Questo metodo obbliga SPIP a visitare
regolarmente i siti in repertorio;
in tal caso si pu&ograve; verificare un leggero rallentamento del tuo sito.',
'texte_vide' => 'vuoto',
'texte_vider_cache' => 'Svuota la cache',
'titre_admin_effacer' => 'Manutenzione tecnica',
'titre_admin_tech' => 'Manutenzione tecnica',
'titre_admin_vider' => 'Manutenzione tecnica',
'titre_articles_syndiques' => 'Articoli in syndication raccolti da questo sito',
'titre_breves' => 'Le brevi',
'titre_cadre_afficher_article' => 'Visualizza gli articoli',
'titre_cadre_afficher_traductions' => 'Visualizzare lo stato delle traduzioni per le seguenti lingue:',
'titre_cadre_ajouter_auteur' => 'AGGIUNGI UN AUTORE: ',
'titre_cadre_forum_administrateur' => 'Forum privato degli amministratori',
'titre_cadre_forum_interne' => 'Forum interno',
'titre_cadre_interieur_rubrique' => 'All\'interno della rubrica',
'titre_cadre_numero_auteur' => 'AUTORE NUMERO',
'titre_cadre_signature_obligatoire' => '<b>Firma</b> [Obbligatoria]<br />',
'titre_compacter_script_css' => 'Compressione degli script e dei CSS',
'titre_compresser_flux_http' => 'Compressione del flusso HTTP',
'titre_config_contenu_notifications' => 'Notifiche',
'titre_config_contenu_prive' => 'Nell\'area riservata',
'titre_config_contenu_public' => 'Sul sito pubblico',
'titre_config_fonctions' => 'Configurazione del sito',
'titre_config_forums_prive' => 'Forum dell\'area riservata',
'titre_config_groupe_mots_cles' => 'Configurazione dei gruppi di parole chiave',
'titre_configuration' => 'Configurazione del sito',
'titre_conflit_edition' => 'Conflitto all\'atto dell\'edizione',
'titre_connexion_ldap' => 'Opzioni: <b>La connessione LDAP</b>',
'titre_dernier_article_syndique' => 'Ultimi articoli in syndication',
'titre_documents_joints' => 'Documenti allegati',
'titre_evolution_visite' => 'Evoluzione delle visite',
'titre_forum_suivi' => 'Monitoraggio dei forum',
'titre_gauche_mots_edit' => 'PAROLA CHIAVE NUMERO:',
'titre_groupe_mots' => 'GRUPPO DI PAROLE CHIAVE:',
'titre_langue_article' => 'LINGUA DELL\'ARTICOLO',
'titre_langue_breve' => 'LINGUA DELLA BREVE',
'titre_langue_rubrique' => 'LINGUA DELLA RUBRICA',
'titre_langue_trad_article' => 'LINGUA E TRADUZIONI DELL\'ARTICOLO',
'titre_les_articles' => 'GLI ARTICOLI',
'titre_messagerie_agenda' => 'Messagistica e agenda',
'titre_mots_cles_dans_forum' => 'Parole chiave nel forum del sito pubblico',
'titre_mots_tous' => 'Le parole chiave',
'titre_naviguer_dans_le_site' => 'Navigare nel sito...',
'titre_nouveau_groupe' => 'Nuovo gruppo',
'titre_nouvelle_breve' => 'Nuova breve',
'titre_nouvelle_rubrique' => 'Nuova rubrica',
'titre_numero_rubrique' => 'RUBRICA NUMERO:',
'titre_page_admin_effacer' => 'Manutenzione tecnica: svuota il database',
'titre_page_articles_edit' => 'Modifica: @titre@',
'titre_page_articles_page' => 'Gli articoli',
'titre_page_articles_tous' => 'Tutto il sito',
'titre_page_auteurs' => 'Visitatori',
'titre_page_breves' => 'Brevi',
'titre_page_breves_edit' => 'Modifica la breve: &laquo;@titre@&raquo;',
'titre_page_calendrier' => 'Calendario @nom_mois@ @annee@',
'titre_page_config_contenu' => 'Configurazione del sito',
'titre_page_config_fonctions' => 'Configurazione del sito',
'titre_page_configuration' => 'Configurazione del sito',
'titre_page_controle_petition' => 'Monitoraggio delle petizioni',
'titre_page_delete_all' => 'eliminazione totale e irreversible',
'titre_page_documents_liste' => 'I documenti delle rubriche',
'titre_page_forum' => 'Forum degli amministratori',
'titre_page_forum_envoi' => 'Invia un messaggio',
'titre_page_forum_suivi' => 'Monitoraggio dei forum',
'titre_page_index' => 'Area riservata',
'titre_page_message_edit' => 'Scrivere un messaggio',
'titre_page_messagerie' => 'I tuoi messaggi',
'titre_page_mots_tous' => 'Parole chiave',
'titre_page_recherche' => 'Risultati della ricerca @recherche@',
'titre_page_sites_tous' => 'I siti repertoriati',
'titre_page_statistiques' => 'Statistiche per rubrica',
'titre_page_statistiques_messages_forum' => 'Messaggi dei forum',
'titre_page_statistiques_referers' => 'Statistiche (link al tuo sito)',
'titre_page_statistiques_signatures_jour' => 'Numero di firme al giorno',
'titre_page_statistiques_signatures_mois' => 'Numero di firme al mese',
'titre_page_statistiques_visites' => 'Statistiche delle visite',
'titre_page_upgrade' => 'Aggiornamento di SPIP',
'titre_publication_articles_post_dates' => 'Pubblicazione di articoli postdatati',
'titre_referencement_sites' => 'Repertorio di siti e syndication',
'titre_referencer_site' => 'Inserire il sito in repertorio:',
'titre_rendez_vous' => 'APPUNTAMENTO:',
'titre_reparation' => 'Riparazione',
'titre_site_numero' => 'SITO NUMERO:',
'titre_sites_proposes' => 'I siti proposti',
'titre_sites_references_rubrique' => 'I siti repertoriati in questa rubrica',
'titre_sites_syndiques' => 'I siti in syndication',
'titre_sites_tous' => 'I siti repertoriati',
'titre_suivi_petition' => 'Monitoraggio delle petizioni',
'titre_syndication' => 'Syndication di siti',
'titre_type_urls' => 'Tipo di indirizzi URL',
'tls_ldap' => 'Transport Layer Security:',
'tout_dossier_upload' => 'Tutta la cartella @upload@',
'trad_article_inexistant' => 'Non esiste un articolo con questo numero.',
'trad_article_traduction' => 'Tutte le versioni di questo articolo:',
'trad_deja_traduit' => 'Errore: non &egrave; possibile collegare questo articolo al numero richiesto.',
'trad_delier' => 'Non collegare pi&ugrave; questo articolo alle sue traduzioni',
'trad_lier' => 'Questo articolo &egrave; una traduzione dell\'articolo numero:',
'trad_new' => 'Scrivere una nuova traduzione dell\'articolo',

// U
'upload_fichier_zip' => 'File ZIP',
'upload_fichier_zip_texte' => 'Il file proposto &egrave; un file ZIP.',
'upload_fichier_zip_texte2' => 'Questo file pu&ograve; essere:',
'upload_info_mode_document' => 'Mettere questa immagine nel portfolio',
'upload_info_mode_image' => 'Eliminare questa immagine dal portfolio',
'upload_limit' => 'Questo file &egrave; troppo grande per il server; la dimensione massima consentita per gli <i>upload</i> &egrave; di @max@.',
'upload_zip_conserver' => 'Conserva l\'archivio al termine dell\'estrazione',
'upload_zip_decompacter' => 'decompresso e ogni elemento installato nel sito. I file che saranno installati nel sito sono:',
'upload_zip_telquel' => 'installato cos&igrave; com\'&egrave; in quanto archivio compresso Zip;',
'upload_zip_titrer' => 'Dare i titoli in base al nome dei file',
'utf8_convert_attendez' => 'Attendi qualche secondo e aggiorna la pagina.',
'utf8_convert_avertissement' => 'Stai per convertire il contenuto del proprio database (articoli, brevi, ecc.) dal set di caratteri <b>@orig@</b> al set di caratteri <b>@charset@</b>.',
'utf8_convert_backup' => 'Non dimenticare di fare prima un backup completo del sito. Inoltre si deve verificare che i modelli e i file lingua sono compatibili @charset@.',
'utf8_convert_erreur_deja' => 'Il tuo sito &egrave; gi&agrave; in @charset@, &egrave; inutile convertirlo...',
'utf8_convert_erreur_orig' => 'Errore: il set di caratteri @charset@ non &egrave; supportato.',
'utf8_convert_termine' => 'Finito!',
'utf8_convert_timeout' => '<b>Importante:</b> in caso di  <i>timeout</i> del server, aggiorna la pagina fino a che non si ottiene il messaggio &laquo;&nbsp;finito&nbsp;&raquo;.',
'utf8_convert_verifier' => 'Ora &egrave; necessario svuotale la cache e verificare che non vi siano problemi sulle pagine pubbliche del sito. In caso di problemi gravi &egrave; stato effettuato un backup dei dati (in formato SQL) nella cartella @rep@.',
'utf8_convertir_votre_site' => 'Convertire il sito in UTF-8',

// V
'version' => 'Versione:',
'version_deplace_rubrique' => 'Spostato da <b>&laquo;&nbsp;@from@&nbsp;&raquo;</b> a <b>&laquo;&nbsp;@to@&nbsp;&raquo;</b>.',
'version_initiale' => 'Versione iniziale'
);

?>
